@@ -1,5 +1,5 @@
 ;Liquid War 6 is a unique multiplayer wargame.
-;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 ;
 ;This program is free software; you can redistribute it and/or modify
 ;it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 (define (lw6-console-catch-handler key . args) 
   (if (eq? key 'quit)
-      (c-lw6gfx-send-quit)
+      (c-lw6sys-signal-send-quit)
       (begin
 	(display key)
 	(display "\n")
@@ -44,6 +44,14 @@
 	 )
   )
 
-(define (lw6-console)
+(define (lw6-console-poll)
   (c-lw6cns-poll)
   )
+
+(define (lw6-console-init)
+  (if (lw6-config-is-true? lw6def-display-console)
+      (begin
+	(c-lw6cns-init)
+	(lw6-console-poll) ;; usefull when piping commands at startup
+	))
+  )
