@@ -34,6 +34,7 @@
 		   lw6def-display-hud
 		   lw6def-display-score
 		   lw6def-display-menu
+		   lw6def-display-meta
 		   lw6def-display-progress
 		   lw6def-display-log
 		   lw6def-display-fps
@@ -89,8 +90,8 @@
 			       (lw6-config-get-string lw6def-gfx-quality)))
 	(if (and game-state pilot node-id)
 	    (let* (
-		   (round (c-lw6pil-get-max-round pilot))
-		   (commands (lw6-command-all-local round node-id))
+		   (seq (c-lw6pil-get-max-seq pilot))
+		   (commands (lw6-command-all-local seq node-id))
 		   (main-cursor (lw6-get-cursor "1"))
 		   (main-cursor-id (if main-cursor (hash-ref main-cursor "id") "0"))
 		   ;(main-cursor-x (if main-cursor (hash-ref main-cursor "x") 0))
@@ -150,6 +151,7 @@
       (lw6-display-param-set! lw6def-display-hud #f)
       (lw6-display-param-set! lw6def-display-score #f)
       (lw6-display-param-set! lw6def-display-menu #f)
+      (lw6-display-param-set! lw6def-display-meta #f)
       )))
 
 (define lw6-display-idle-setup
@@ -163,6 +165,7 @@
       (lw6-display-param-set! lw6def-display-hud #f)
       (lw6-display-param-set! lw6def-display-score #f)
       (lw6-display-param-set-boolean-from-config! lw6def-display-menu)
+      (lw6-display-param-set-boolean-from-config! lw6def-display-meta)
       )))
 
 (define lw6-display-preview-setup
@@ -176,6 +179,7 @@
       (lw6-display-param-set! lw6def-display-hud #f)
       (lw6-display-param-set! lw6def-display-score #f)
       (lw6-display-param-set-boolean-from-config! lw6def-display-menu)
+      (lw6-display-param-set-boolean-from-config! lw6def-display-meta)
       )))
 
 (define lw6-display-running-setup
@@ -189,6 +193,7 @@
       (lw6-display-param-set-boolean-from-config! lw6def-display-hud)
       (lw6-display-param-set! lw6def-display-score #f)
       (lw6-display-param-set-boolean-from-config! lw6def-display-menu)
+      (lw6-display-param-set! lw6def-display-meta #f)
       )))
 
 (define lw6-display-score-setup
@@ -202,6 +207,7 @@
       (lw6-display-param-set! lw6def-display-hud #f)
       (lw6-display-param-set-boolean-from-config! lw6def-display-score)
       (lw6-display-param-set-boolean-from-config! lw6def-display-menu)
+      (lw6-display-param-set-boolean-from-config! lw6def-display-meta)
       )))
 
 (define lw6-display-no-score-setup
