@@ -1,5 +1,5 @@
 ;Liquid War 6 is a unique multiplayer wargame.
-;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 ;
 ;This program is free software; you can redistribute it and/or modify
 ;it under the terms of the GNU General Public License as published by
@@ -21,72 +21,72 @@
 (define lw6-root-menu-quick-start-item
   (lambda ()
     (let (
-	  (item (lw6-menu-item-template (_ "Quick start")))
+	  (menuitem (lw6-menu-item-template (_ "Quick start")
+					    (_ "Start playing now!")))
 	  )
       (begin
-	(assoc-set! item "selected" #t)
-	item
+	(assoc-set! menuitem "selected" #t)
+	(assoc-set! menuitem "on-valid" (lambda (mi) (lw6-game-start-local-step1 lw6-game-start-quick-step2)))
+	menuitem
 	))))
 
-(define lw6-root-menu-local-item
+(define lw6-root-menu-play-item
   (lambda ()
     (let (
-	  (item (lw6-menu-item-template (_ "Local game")))
+	  (menuitem (lw6-menu-item-template (_ "Play")
+					    (_ "Start a new game")))
 	  )
       (begin
-	item
-	))))
-
-(define lw6-root-menu-network-item
-  (lambda ()
-    (let (
-	  (item (lw6-menu-item-template (_ "Network game")))
-	  )
-      (begin
-	item
+	(assoc-set! menuitem "on-valid" (lambda (mi) (lw6-push-menu (lw6-play-menu))))
+	menuitem
 	))))
 
 (define lw6-root-menu-map-item
   (lambda ()
     (let (
-	  (item (lw6-menu-item-template (_ "Choose map")))
+	  (menuitem (lw6-menu-item-template (_ "Choose map")
+					    (_ "Browse map directory and choose a map to play on")))
 	  )
       (begin
-	(assoc-set! item "on-valid" (lambda () (lw6-push-menu (lw6-map-menu (lw6-config-get-string "chosen-map")))))
-	item
+	(assoc-set! menuitem "on-valid" (lambda (mi) (lw6-push-map-menu)))
+	menuitem
 	))))
 
 (define lw6-root-menu-players-item
   (lambda ()
     (let (
-	  (item (lw6-menu-item-template (_ "Players")))
+	  (menuitem (lw6-menu-item-template (_ "Players")
+					    (_ "Choose player name, color (teams), controls (keyboard, mouse, joystick) and populate your map with bots")))
 	  )
       (begin
-	item
+	(assoc-set! menuitem "on-valid" (lambda (mi) (lw6-push-menu (lw6-players-menu))))
+	menuitem
 	))))
 
 (define lw6-root-menu-options-item
   (lambda ()
     (let (
-	  (item (lw6-menu-item-template (_ "Options")))
+	  (menuitem (lw6-menu-item-template (_ "Options")
+					    (_ "Set up video, sound, game rules, and more")))
 	  )
       (begin
-	(assoc-set! item "on-valid" (lambda () (lw6-push-menu (lw6-options-menu))))
-	item
+	(assoc-set! menuitem "on-valid" (lambda (mi) (lw6-push-menu (lw6-options-menu))))
+	menuitem
 	))))
 
 (define lw6-root-menu
   (lambda()
     (let (
-	  (menu (lw6-menu-template (_ "Welcome to Liquid War 6")))
+	  (menu (lw6-menu-template (_ "Liquid War 6")
+				   (_ "Welcome to Liquid War 6, have fun!")
+				   #f))
 	  )
       (begin
 	(lw6-append-menuitem! menu (lw6-root-menu-quick-start-item))
-	(lw6-append-menuitem! menu (lw6-root-menu-local-item))
-	(lw6-append-menuitem! menu (lw6-root-menu-network-item))
+	(lw6-append-menuitem! menu (lw6-root-menu-play-item))
 	(lw6-append-menuitem! menu (lw6-root-menu-map-item))
 	(lw6-append-menuitem! menu (lw6-root-menu-players-item))
 	(lw6-append-menuitem! menu (lw6-root-menu-options-item))
-	(assoc-set! menu "on-cancel" (lambda () (lw6-push-menu (lw6-exit-menu))))
+	(assoc-set! menu "on-cancel" (lambda (m) (lw6-push-menu (lw6-exit-menu))))
 	menu
 	))))
