@@ -21,7 +21,8 @@
 (define lw6-wait-menu-item
   (lambda ()
     (let (
-	  (menuitem (lw6-menu-item-template (_ "Please wait...")))
+	  (menuitem (lw6-menu-item-template (_ "Please wait...")
+					    #f))
 	  )
       (begin
 	(assoc-set! menuitem "selected" #t)
@@ -29,9 +30,11 @@
 	))))
 
 (define lw6-wait-menu
-  (lambda()
+  (lambda(help)
     (let (
-	  (menu (lw6-menu-template (_ "Please wait...")))
+	  (menu (lw6-menu-template (_ "Please wait...")
+				   help
+				   #f))
 	  )
       (begin
 	(lw6-append-menuitem! menu (lw6-wait-menu-item))
