@@ -58,10 +58,12 @@
 			     )))))
 
 (define lw6-mover-generic
-  (lambda (get-state-func sensitivity-func max-cursor-speed-func)
+  (lambda (get-state-func pop-fire-func pop-fire2-func sensitivity-func max-cursor-speed-func)
     (lambda (cursor)
       (let* (
 	     (state (get-state-func))
+	     (fire (or (pop-fire-func) (hash-ref cursor "fire")))
+	     (fire2 (or (pop-fire2-func) (hash-ref cursor "fire2")))
 	     (up (assoc-ref state "up"))
 	     (down (assoc-ref state "down"))
 	     (left (assoc-ref state "left"))
@@ -71,6 +73,8 @@
 	     (moved #f)
 	    )
 	(begin
+	  (hash-set! cursor "fire" fire)
+	  (hash-set! cursor "fire2" fire2)
 	  (if up 
 	      (if down
 		  #t		  
@@ -93,7 +97,8 @@
 		(hash-set! cursor "y" (+ (hash-ref cursor "y") (hash-ref cursor "vy")))
 		#t)
 	      #f
-	      ))))))
+	      )
+	)))))
 
 (define lw6-mover-mouse-func
   (lambda (cursor)
@@ -101,45 +106,77 @@
 	(
 	 (dsp (lw6-get-game-global "dsp"))
 	 (mouse-state (c-lw6gui-mouse-poll-move dsp))
-	 (map-x (assoc-ref mouse-state "map-x"))
-	 (map-y (assoc-ref mouse-state "map-y"))
+	 ;; Default binding is to map left simple on fire, and right 
+	 ;; on alternate fire, but on a tablet PC and/or tactile screen 
+	 ;; we use simple/double-clicks instead
+	 (use-double-click (lw6-config-is-true? lw6def-use-double-click))
+	 (fire (or (if use-double-click
+		       (c-lw6gui-mouse-pop-double-click dsp) #f)
+		   (c-lw6gui-mouse-pop-button-right dsp)
+		   (hash-ref cursor "fire")))
+	 (fire2 (or (if use-double-click
+			(c-lw6gui-mouse-pop-triple-click dsp) #f)
+		    (c-lw6gui-mouse-pop-button-middle dsp)
+		    (hash-ref cursor "fire2")))
+	 (map-pos-x (assoc-ref mouse-state "map-pos-x"))
+	 (map-pos-y (assoc-ref mouse-state "map-pos-y"))
 	 (menu-esc (assoc-ref mouse-state "menu-esc"))
 	 )
-      (if (or mouse-state (hash-ref cursor "mouse-controlled"))
-	  (begin
-	    (if (not mouse-state)
-		(begin
-		  (set! mouse-state (c-lw6gui-mouse-get-state dsp))
-		  (set! map-x (assoc-ref mouse-state "map-x"))
-		  (set! map-y (assoc-ref mouse-state "map-y"))
-		  ))
-	    (if (or (not (= (hash-ref cursor "x") map-x))
-		    (not (= (hash-ref cursor "y") map-y)))
-		(begin
-		  (hash-set! cursor "x" map-x)
-		  (hash-set! cursor "y" map-y)
-		  (hash-set! cursor "mouse-controlled" #t)
-		  #t)
-		#f)
-	    #t
-	    )
-	  #f
-	  ))))
+      (begin
+	;; We flush the buttons, test is done
+	(c-lw6gui-mouse-pop-button-left dsp)
+	(c-lw6gui-mouse-pop-button-right dsp)
+	(c-lw6gui-mouse-pop-button-middle dsp)
+	(c-lw6gui-mouse-pop-simple-click dsp)
+	(c-lw6gui-mouse-pop-double-click dsp)
+	(c-lw6gui-mouse-pop-triple-click dsp)
+	(hash-set! cursor "fire" fire)
+	(hash-set! cursor "fire2" fire2)
+	(if (or mouse-state (hash-ref cursor "mouse-controlled"))
+	    (begin
+	      (if (not mouse-state)
+		  (begin
+		    (set! mouse-state (c-lw6gui-mouse-get-state dsp))
+		    (set! map-pos-x (assoc-ref mouse-state "map-pos-x"))
+		    (set! map-pos-y (assoc-ref mouse-state "map-pos-y"))
+		    ))
+	      (if (or (not (= (hash-ref cursor "x") map-pos-x))
+		      (not (= (hash-ref cursor "y") map-pos-y))
+	              (not (= (hash-ref cursor "map-pos-x") map-pos-x))
+		      (not (= (hash-ref cursor "map-pos-y") map-pos-y)))
+		  (begin
+		    (hash-set! cursor "x" map-pos-x)
+		    (hash-set! cursor "y" map-pos-y)
+		    (hash-set! cursor "map-pos-x" map-pos-x)
+		    (hash-set! cursor "map-pos-y" map-pos-y)
+		    (hash-set! cursor "mouse-controlled" #t)
+		    #t)
+		  #f)
+	      #t
+	      )
+	    #f
+	    )))))
 
 (define lw6-mover-keyboard-func
   (lw6-mover-generic (lambda () (c-lw6gui-keyboard-get-move-pad (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-keyboard-pop-key-ctrl (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-keyboard-pop-key-alt (lw6-get-game-global "dsp")))
 		     (lambda () (lw6-config-get-number lw6def-cursor-sensitivity))
 		     (lambda () (lw6-config-get-number lw6def-max-cursor-speed))
 		     ))
 
 (define lw6-mover-joystick1-func
   (lw6-mover-generic (lambda () (c-lw6gui-joystick1-get-move-pad (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-joystick1-pop-button-c (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-joystick1-pop-button-d (lw6-get-game-global "dsp")))
 		     (lambda () (lw6-config-get-number lw6def-cursor-sensitivity))
 		     (lambda () (lw6-config-get-number lw6def-max-cursor-speed))
 		     ))
 
 (define lw6-mover-joystick2-func
   (lw6-mover-generic (lambda () (c-lw6gui-joystick2-get-move-pad (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-joystick2-pop-button-c (lw6-get-game-global "dsp")))
+		     (lambda () (c-lw6gui-joystick2-pop-button-d (lw6-get-game-global "dsp")))
 		     (lambda () (lw6-config-get-number lw6def-cursor-sensitivity))
 		     (lambda () (lw6-config-get-number lw6def-max-cursor-speed))
 		     ))
@@ -154,6 +191,8 @@
 	  (begin
 	    (hash-set! cursor "x" (assoc-ref pos "x"))
 	    (hash-set! cursor "y" (assoc-ref pos "y"))
+	    (hash-set! cursor "fire" (or (assoc-ref pos "fire") (hash-ref cursor "fire")))
+	    (hash-set! cursor "fire2" (or (assoc-ref pos "fire2") (hash-ref cursor "fire2")))
 	    ;;(tmp (list (assoc-ref pos "x") (assoc-ref pos "y")))
 	    )))))
 
@@ -173,12 +212,47 @@
 						   (assoc-ref joystick2-state dir))))
 				   (list "up" "down" "left" "right"))
 				))
+			  (lambda () (or (c-lw6gui-keyboard-pop-key-ctrl (lw6-get-game-global "dsp"))
+					 (c-lw6gui-joystick1-pop-button-c (lw6-get-game-global "dsp"))
+					 (c-lw6gui-joystick2-pop-button-c (lw6-get-game-global "dsp"))))
+			  (lambda () (or (c-lw6gui-keyboard-pop-key-alt (lw6-get-game-global "dsp"))
+					 (c-lw6gui-joystick1-pop-button-d (lw6-get-game-global "dsp"))
+					 (c-lw6gui-joystick2-pop-button-d (lw6-get-game-global "dsp"))))
 			  (lambda () (lw6-config-get-number lw6def-cursor-sensitivity))
 			  (lambda () (lw6-config-get-number lw6def-max-cursor-speed))
 			  ) cursor)
       (lw6-mover-mouse-func cursor)
       )))
 
+(define lw6-mover-semi-universal-1-func
+  (lambda (cursor)
+    (begin
+      (lw6-mover-joystick1-func cursor)
+      (lw6-mover-mouse-func cursor)
+      )))
+
+(define lw6-mover-semi-universal-2-func
+  (lambda (cursor)
+    ((lw6-mover-generic (lambda () 
+			  (let* (
+				 (dsp (lw6-get-game-global "dsp"))
+				 (keyboard-state (c-lw6gui-keyboard-get-move-pad dsp))
+				 (joystick2-state (c-lw6gui-joystick2-get-move-pad dsp))
+				 )
+			    (map (lambda (dir) 
+				   (cons dir (or (assoc-ref keyboard-state dir)
+						 (assoc-ref joystick2-state dir))))
+				 (list "up" "down" "left" "right"))
+				))
+			(lambda () (or (c-lw6gui-keyboard-pop-key-ctrl (lw6-get-game-global "dsp"))
+				       (c-lw6gui-joystick2-pop-button-c (lw6-get-game-global "dsp"))))
+			(lambda () (or (c-lw6gui-keyboard-pop-key-alt (lw6-get-game-global "dsp"))
+				       (c-lw6gui-joystick2-pop-button-d (lw6-get-game-global "dsp"))))
+			(lambda () (lw6-config-get-number lw6def-cursor-sensitivity))
+			(lambda () (lw6-config-get-number lw6def-max-cursor-speed))
+			) cursor)
+    ))
+
 (define lw6-mover
   (lambda ()
     (map (lambda (cursor-key) (let* (
@@ -190,7 +264,8 @@
 				    (begin
 				      (mover cursor)
 				      (let* (					    
-					     (coords (c-lw6pil-fix-coords game-state (hash-ref cursor "x") (hash-ref cursor "y") 0.0))
+					     (coords (c-lw6pil-fix-coords-x10 game-state (hash-ref cursor "x") (hash-ref cursor "y") 0.0))
+					     ;; (coords (list (cons "x" (hash-ref cursor "x")) (cons "y" (hash-ref cursor "y")) 0.0))
 					     (x (assoc-ref coords "x"))
 					     (y (assoc-ref coords "y"))
 					     )
@@ -200,4 +275,4 @@
 					  ))
 				      )
 				    )))
-	 (list "1" "2" "3" "4"))))
+	 lw6-cursor-keys)))
