@@ -30,5 +30,5 @@
 	   (not (lw6-config-is-true? lw6def-quick-start)))
 	  (begin
 	    (lw6-play-fx-splash)
-	    (lw6-wait-any-key)
+	    (lw6-wait-until-any-key)
 	    (lw6-play-fx-beep-valid))))))
\ No newline at end of file
