@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ merge_func (void *func_data, void *data)
 	      if (env)
 		{
 		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _
+			      _x_
 			      ("key \"%s\" set to \"%s\" by environment variable \"%s\""),
 			      keyword, value_converted, env);
 		  LW6SYS_FREE (env);
@@ -90,7 +90,7 @@ _lw6cfg_merge_env (_lw6cfg_context_t * cfg_context)
   int ret = 0;
   lw6sys_list_t *keywords;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("merging environment variables"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("merging environment variables"));
   keywords = lw6hlp_list ();
   if (keywords)
     {
