@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,25 +28,14 @@
 #include "mod-http-internal.h"
 
 char *
-_mod_http_repr (_http_context_t * http_context,
-		lw6cli_connection_t * connection)
+_mod_http_repr (_mod_http_context_t * http_context,
+		lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
   ret =
-    lw6sys_new_sprintf (_("http connexion on \"%s\""),
-			connection->server_url);
-
-  return ret;
-}
-
-char *
-_mod_http_error (_http_context_t * http_context,
-		 lw6cli_connection_t * connection)
-{
-  char *ret = NULL;
-
-  // todo
+    lw6sys_new_sprintf (_x_ ("http connexion on \"%s\""),
+			connection->remote_url);
 
   return ret;
 }
