@@ -36,7 +36,9 @@
 #define TEST_DURATION_MENU 500
 #define TEST_DURATION_VIEW 500
 #define TEST_DURATION_HUD 10000
-#define TEST_MENU_LABEL "My menu"
+#define TEST_MENU_TITLE "My menu"
+#define TEST_MENU_HELP "This is a sample menu"
+#define TEST_MENU_POPUP ""
 #define TEST_MENU_ESC "Esc"
 #define TEST_MENU_ENABLE_ESC 0
 #define TEST_MENU_ALLOW_SCROLL 0
@@ -217,6 +219,7 @@ test_menu (lw6gfx_backend_t * backend)
     lw6gui_menu_t *menu = NULL;
     int i;
     char *menuitem_label;
+    char *menuitem_tooltip;
     int64_t ticks;
     float progress;
 
@@ -226,8 +229,8 @@ test_menu (lw6gfx_backend_t * backend)
     if (look)
       {
 	menu =
-	  lw6gui_menu_new (TEST_MENU_LABEL, TEST_MENU_ESC,
-			   TEST_MENU_ENABLE_ESC);
+	  lw6gui_menu_new (TEST_MENU_TITLE, TEST_MENU_HELP, TEST_MENU_POPUP,
+			   TEST_MENU_ESC, TEST_MENU_ENABLE_ESC);
 	if (menu)
 	  {
 	    for (i = 0; i < TEST_MENU_NB_MENUITEMS; ++i)
@@ -236,14 +239,24 @@ test_menu (lw6gfx_backend_t * backend)
 		  lw6sys_new_sprintf (_x_ ("Test menuitem %d"), i);
 		if (menuitem_label)
 		  {
-		    menuitem =
-		      lw6gui_menuitem_new (menuitem_label, TEST_MENU_COLOR, 1,
-					   0,
-					   i == TEST_MENU_COLORED_MENUITEM);
-		    if (menuitem)
+		    menuitem_tooltip =
+		      lw6sys_new_sprintf (_x_
+					  ("Tooltip for menuitem %d\nExplaining how it works\nIt works as follows:\n...it works!"),
+					  i);
+		    if (menuitem_tooltip)
 		      {
-			lw6gui_menu_append (menu, menuitem,
-					    lw6sys_get_uptime ());
+			menuitem =
+			  lw6gui_menuitem_new (menuitem_label,
+					       menuitem_tooltip,
+					       TEST_MENU_COLOR, 1, 0,
+					       i ==
+					       TEST_MENU_COLORED_MENUITEM);
+			if (menuitem)
+			  {
+			    lw6gui_menu_append (menu, menuitem,
+						lw6sys_get_uptime ());
+			  }
+			LW6SYS_FREE (menuitem_tooltip);
 		      }
 		    LW6SYS_FREE (menuitem_label);
 		  }
@@ -258,8 +271,8 @@ test_menu (lw6gfx_backend_t * backend)
 			     ticks)) / ((float) TEST_DURATION_MENU);
 		if (!lw6gfx_display (backend,
 				     LW6GUI_DISPLAY_BACKGROUND |
-				     LW6GUI_DISPLAY_MENU |
-				     LW6GUI_DISPLAY_PROGRESS, look, NULL,
+				     LW6GUI_DISPLAY_MENU | LW6GUI_DISPLAY_META
+				     | LW6GUI_DISPLAY_PROGRESS, look, NULL,
 				     NULL, NULL, 0, menu, progress, 0, 0,
 				     NULL, 0, 0, 0, 0))
 		  {
@@ -540,6 +553,11 @@ lw6gfx_test (int mode)
       lw6pil_test (mode);
       lw6gui_test (mode);
       lw6vox_test (mode);
+      /*
+       * No lw6dyn_test, see https://savannah.gnu.org/bugs/index.php?35017
+       * this function is available only in non-allinone mode.
+       */
+      // lw6dyn_test (mode);
     }
 
   if (mode)
