@@ -29,9 +29,9 @@
 #include "../../mod-gl.h"
 #include "gl-floating-internal.h"
 
-void
-display_clock (mod_gl_utils_context_t * utils_context,
-	       _mod_gl_hud_floating_context_t * floating_context)
+static void
+_display_clock (mod_gl_utils_context_t * utils_context,
+		_mod_gl_hud_floating_context_t * floating_context)
 {
   float x1, x2, y1, y2, dw, dh;
   float size_factor =
@@ -59,17 +59,20 @@ display_clock (mod_gl_utils_context_t * utils_context,
     }
 }
 
-void
-display_gauges (mod_gl_utils_context_t * utils_context,
-		_mod_gl_hud_floating_context_t * floating_context)
+static void
+_display_gauges (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_hud_floating_context_t * floating_context)
 {
   float x1, x2, y1, y2, w, h;
   float text_w, text_h, text_x1, text_x2, text_y1, text_y2, text_dw, text_dh;
   float size_factor_screen =
     sqrt (utils_context->video_mode.width * utils_context->video_mode.height);
   float size_factor_score;
+  float size_factor_heartbeat;
   float size_factor;
   float ratio;
+  int weapon_per1000_left;
+  float charge;
   float inner, outer;
   int slices, loops;
   int i;
@@ -94,11 +97,41 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 	  team_color = floating_context->score_array.scores[i].team_color;
 	  if (team_color >= 0)
 	    {
+	      weapon_per1000_left =
+		lw6ker_game_state_get_weapon_per1000_left
+		(floating_context->game_state, team_color);
+	      if (weapon_per1000_left > 0)
+		{
+		  charge = lw6sys_min (1000, weapon_per1000_left) / 1000.0f;
+		}
+	      else
+		{
+		  charge =
+		    lw6sys_min (1000,
+				lw6ker_game_state_get_charge_per1000
+				(floating_context->game_state,
+				 team_color)) / 1000.0f;
+		}
 	      size_factor_score =
 		ratio * floating_context->const_data.gauge_max_size + (1.0f -
 								       ratio)
 		* floating_context->const_data.gauge_min_size;
-	      size_factor = size_factor_screen * size_factor_score;
+	      size_factor_heartbeat = (lw6ker_game_state_get_charge_per1000
+				       (floating_context->game_state,
+					team_color) >=
+				       1000) ?
+		lw6sys_math_heartbeat (mod_gl_utils_timer_get_uptime
+				       (utils_context),
+				       floating_context->const_data.
+				       gauge_heartbeat_period,
+				       floating_context->
+				       const_data.gauge_relative_heartbeat_min,
+				       floating_context->
+				       const_data.gauge_relative_heartbeat_max)
+		: 1.0f;
+	      size_factor =
+		size_factor_screen * size_factor_score *
+		size_factor_heartbeat;
 	      w = size_factor;
 	      h = size_factor;
 
@@ -107,7 +140,7 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 
 	      slices = floating_context->const_data.gauge_slices;
 	      loops = floating_context->const_data.gauge_loops;
-	      sweep1 = ratio * floating_context->const_data.gauge_sweep;
+	      sweep1 = charge * floating_context->const_data.gauge_sweep;
 	      sweep2 = floating_context->const_data.gauge_sweep - sweep1;
 
 	      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -274,14 +307,52 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-display_hud (mod_gl_utils_context_t * utils_context,
-	     _mod_gl_hud_floating_context_t * floating_context)
+_display_weapon (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_hud_floating_context_t * floating_context)
+{
+  int team_color = 0;
+  int weapon_id = 0;
+  int per1000_left = 0;
+  mod_gl_utils_bitmap_t *bitmap = NULL;
+  float x1, y1, x2, y2;
+  int transparency;
+
+  glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  glEnable (GL_BLEND);
+
+  if (lw6ker_game_state_get_latest_weapon
+      (floating_context->game_state, &team_color, &weapon_id, &per1000_left))
+    {
+      transparency =
+	((per1000_left * floating_context->const_data.weapon_ambiance_alpha1 +
+	  (1000 -
+	   per1000_left) *
+	  floating_context->const_data.weapon_ambiance_alpha2) *
+	 MOD_GL_UTILS_TRANSPARENCY_SCALE) / 1000;
+      transparency =
+	lw6sys_max (0,
+		    lw6sys_min (MOD_GL_UTILS_TRANSPARENCY_SCALE,
+				transparency));
+      bitmap =
+	utils_context->
+	textures_1x1.team_colors_transparency[team_color][transparency];
+      x1 = y1 = 0.0f;
+      x2 = utils_context->video_mode.width;
+      y2 = utils_context->video_mode.height;
+      mod_gl_utils_bitmap_display (utils_context, bitmap, x1, y1, x2, y2);
+    }
+}
+
+static void
+_display_hud (mod_gl_utils_context_t * utils_context,
+	      _mod_gl_hud_floating_context_t * floating_context)
 {
   glMatrixMode (GL_TEXTURE);
   glPushMatrix ();
   glLoadIdentity ();
-  display_clock (utils_context, floating_context);
-  display_gauges (utils_context, floating_context);
+  _display_clock (utils_context, floating_context);
+  _display_gauges (utils_context, floating_context);
+  _display_weapon (utils_context, floating_context);
   glMatrixMode (GL_TEXTURE);
   glPopMatrix ();
 }
@@ -294,11 +365,13 @@ _mod_gl_hud_floating_display_hud (mod_gl_utils_context_t * utils_context,
 				  lw6ker_game_state_t * game_state,
 				  lw6pil_local_cursors_t * local_cursors)
 {
+  _mod_gl_hud_floating_context_begin_hud (utils_context, floating_context);
   _mod_gl_hud_floating_context_update_hud (utils_context, floating_context,
 					   look, game_state, local_cursors);
 
   mod_gl_utils_set_render_mode_2d_blend (utils_context);
-  display_hud (utils_context, floating_context);
+  _display_hud (utils_context, floating_context);
+  _mod_gl_hud_floating_context_end_hud (utils_context, floating_context);
 }
 
 void
@@ -314,9 +387,9 @@ mod_gl_hud_floating_display_hud (mod_gl_utils_context_t * utils_context,
 				    local_cursors);
 }
 
-void
-display_pie (mod_gl_utils_context_t * utils_context,
-	     _mod_gl_hud_floating_context_t * floating_context)
+static void
+_display_pie (mod_gl_utils_context_t * utils_context,
+	      _mod_gl_hud_floating_context_t * floating_context)
 {
   int i = 0;
   float x0, y0, dx, dy, angle1, angle2, angle_offset;
@@ -463,13 +536,13 @@ display_pie (mod_gl_utils_context_t * utils_context,
 }
 
 static void
-display_score (mod_gl_utils_context_t * utils_context,
-	       _mod_gl_hud_floating_context_t * floating_context)
+_display_score (mod_gl_utils_context_t * utils_context,
+		_mod_gl_hud_floating_context_t * floating_context)
 {
   glMatrixMode (GL_TEXTURE);
   glPushMatrix ();
   glLoadIdentity ();
-  display_pie (utils_context, floating_context);
+  _display_pie (utils_context, floating_context);
   glMatrixMode (GL_TEXTURE);
   glPopMatrix ();
 }
@@ -482,11 +555,13 @@ _mod_gl_hud_floating_display_score (mod_gl_utils_context_t * utils_context,
 				    lw6ker_game_state_t * game_state,
 				    lw6pil_local_cursors_t * local_cursors)
 {
+  _mod_gl_hud_floating_context_begin_score (utils_context, floating_context);
   _mod_gl_hud_floating_context_update_score (utils_context, floating_context,
 					     look, game_state, local_cursors);
 
   mod_gl_utils_set_render_mode_2d_blend (utils_context);
-  display_score (utils_context, floating_context);
+  _display_score (utils_context, floating_context);
+  _mod_gl_hud_floating_context_end_score (utils_context, floating_context);
 }
 
 void
