@@ -54,6 +54,46 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			   &const_data->sphere_slices_min);
       lw6cfg_read_xml_int (key, value, "sphere-blink-period",
 			   &const_data->sphere_blink_period);
+      lw6cfg_read_xml_int (key, value, "tooltip-max-width",
+			   &const_data->tooltip_max_width);
+      lw6cfg_read_xml_int (key, value, "tooltip-max-height",
+			   &const_data->tooltip_max_height);
+      lw6cfg_read_xml_int (key, value, "tooltip-border-size",
+			   &const_data->tooltip_border_size);
+      lw6cfg_read_xml_int (key, value, "tooltip-margin-size",
+			   &const_data->tooltip_margin_size);
+      lw6cfg_read_xml_int (key, value, "tooltip-reformat-width",
+			   &const_data->tooltip_reformat_width);
+      lw6cfg_read_xml_int (key, value, "help-max-width",
+			   &const_data->help_max_width);
+      lw6cfg_read_xml_int (key, value, "help-max-height",
+			   &const_data->help_max_height);
+      lw6cfg_read_xml_int (key, value, "help-border-size",
+			   &const_data->help_border_size);
+      lw6cfg_read_xml_int (key, value, "help-margin-size",
+			   &const_data->help_margin_size);
+      lw6cfg_read_xml_int (key, value, "help-reformat-width",
+			   &const_data->help_reformat_width);
+      lw6cfg_read_xml_int (key, value, "breadcrumbs-max-width",
+			   &const_data->breadcrumbs_max_width);
+      lw6cfg_read_xml_int (key, value, "breadcrumbs-max-height",
+			   &const_data->breadcrumbs_max_height);
+      lw6cfg_read_xml_int (key, value, "breadcrumbs-border-size",
+			   &const_data->breadcrumbs_border_size);
+      lw6cfg_read_xml_int (key, value, "breadcrumbs-margin-size",
+			   &const_data->breadcrumbs_margin_size);
+      lw6cfg_read_xml_int (key, value, "breadcrumbs-reformat-width",
+			   &const_data->breadcrumbs_reformat_width);
+      lw6cfg_read_xml_int (key, value, "popup-max-width",
+			   &const_data->popup_max_width);
+      lw6cfg_read_xml_int (key, value, "popup-max-height",
+			   &const_data->popup_max_height);
+      lw6cfg_read_xml_int (key, value, "popup-border-size",
+			   &const_data->popup_border_size);
+      lw6cfg_read_xml_int (key, value, "popup-margin-size",
+			   &const_data->popup_margin_size);
+      lw6cfg_read_xml_int (key, value, "popup-reformat-width",
+			   &const_data->popup_reformat_width);
     }
 
   if (!strcmp (element, "float"))
@@ -86,6 +126,22 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->esc_cyl_height_offset);
       lw6cfg_read_xml_float (key, value, "esc-rotate",
 			     &const_data->esc_rotate);
+      lw6cfg_read_xml_float (key, value, "tooltip-alpha-bg",
+			     &const_data->tooltip_alpha_bg);
+      lw6cfg_read_xml_float (key, value, "tooltip-relative-size",
+			     &const_data->tooltip_relative_size);
+      lw6cfg_read_xml_float (key, value, "help-alpha-bg",
+			     &const_data->help_alpha_bg);
+      lw6cfg_read_xml_float (key, value, "help-relative-size",
+			     &const_data->help_relative_size);
+      lw6cfg_read_xml_float (key, value, "breadcrumbs-alpha-bg",
+			     &const_data->breadcrumbs_alpha_bg);
+      lw6cfg_read_xml_float (key, value, "breadcrumbs-relative-size",
+			     &const_data->breadcrumbs_relative_size);
+      lw6cfg_read_xml_float (key, value, "popup-alpha-bg",
+			     &const_data->popup_alpha_bg);
+      lw6cfg_read_xml_float (key, value, "popup-relative-size",
+			     &const_data->popup_relative_size);
     }
 }
 
