@@ -29,10 +29,11 @@
 
 #define FEEDBACK_BUFFER_SIZE 4096
 
-#define NAME_DEFAULT -1
-#define NAME_PREV -2
-#define NAME_NEXT -3
-#define NAME_ESC -4
+#define _PASS_THROUGH_DEFAULT -1
+#define _PASS_THROUGH_PREV -2
+#define _PASS_THROUGH_NEXT -3
+#define _PASS_THROUGH_ESC -4
+#define _PASS_THROUGH_SELECTED -5
 
 static void
 draw_button_corners (mod_gl_utils_context_t * utils_context,
@@ -113,9 +114,9 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
   int i, n;
   float x, y, x_min, x_max, y_min, y_max;
   lw6gui_menuitem_t *menuitem;
-  mod_gl_utils_bitmap_t *button_cancelitmap = NULL;
+  mod_gl_utils_bitmap_t *button_bitmap = NULL;
   float relative_text_width;
-  int ret = NAME_DEFAULT;
+  int ret = _PASS_THROUGH_DEFAULT;
 
   lw6gui_menu_update_display_range (menu,
 				    cylinder_context->
@@ -134,30 +135,30 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
     {
       draw_spheres_corners (utils_context, cylinder_context, 0, n,
 			    cylinder_context->const_data.nb_spheres,
-			    NAME_PREV);
+			    _PASS_THROUGH_PREV);
     }
   if (menu->first_item_displayed + menu->nb_items_displayed < menu->nb_items)
     {
       draw_spheres_corners (utils_context, cylinder_context, n - 1, n,
 			    cylinder_context->const_data.nb_spheres,
-			    NAME_NEXT);
+			    _PASS_THROUGH_NEXT);
     }
 
   for (i = 0; i < menu->nb_items_displayed; ++i)
     {
       menuitem = menu->items[i + menu->first_item_displayed];
-      button_cancelitmap =
+      button_bitmap =
 	mod_gl_utils_get_button_from_menucache (utils_context, look,
 						menuitem);
-      if (button_cancelitmap)
+      if (button_bitmap)
 	{
 	  //
-	  // If button_cancelitmap doesn't exist, well, we won't die,
+	  // If button_bitmap doesn't exist, well, we won't die,
 	  // we just suppose the button is very large. It practise
 	  // it shouldn't happen for we've drawn them just before.
 	  //
 	  relative_text_width =
-	    ((float) button_cancelitmap->surface->w) /
+	    ((float) button_bitmap->surface->w) /
 	    ((float) MOD_GL_UTILS_MENU_TEXTURE_W);
 	}
       else
@@ -172,18 +173,18 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 
   if (menu->esc_item->enabled)
     {
-      button_cancelitmap =
+      button_bitmap =
 	mod_gl_utils_get_button_from_menucache (utils_context, look,
 						menu->esc_item);
-      if (button_cancelitmap)
+      if (button_bitmap)
 	{
 	  //
-	  // If button_cancelitmap doesn't exist, well, we won't die,
+	  // If button_bitmap doesn't exist, well, we won't die,
 	  // we just suppose the button is very large. It practise
 	  // it shouldn't happen for we've drawn them just before.
 	  //
 	  relative_text_width =
-	    ((float) button_cancelitmap->surface->w) /
+	    ((float) button_bitmap->surface->w) /
 	    ((float) MOD_GL_UTILS_MENU_TEXTURE_W);
 	}
       else
@@ -191,7 +192,7 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 	  relative_text_width = 1.0f;
 	}
       draw_button_corners (utils_context, cylinder_context, -1, n,
-			   relative_text_width, NAME_ESC);
+			   relative_text_width, _PASS_THROUGH_ESC);
     }
 
   glRenderMode (GL_RENDER);	// back to normal mode
@@ -242,17 +243,17 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 
   switch (ret)
     {
-    case NAME_PREV:
+    case _PASS_THROUGH_PREV:
       (*position) = -1;
       (*scroll) = -1;
       (*esc) = 0;
       break;
-    case NAME_NEXT:
+    case _PASS_THROUGH_NEXT:
       (*position) = -1;
       (*scroll) = +1;
       (*esc) = 0;
       break;
-    case NAME_ESC:
+    case _PASS_THROUGH_ESC:
       (*position) = -1;
       (*scroll) = 0;
       (*esc) = 1;
@@ -263,3 +264,74 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
       (*esc) = 0;
     }
 }
+
+void
+_mod_gl_menu_cylinder_get_cylinder_right_point (mod_gl_utils_context_t *
+						utils_context,
+						_mod_gl_menu_cylinder_context_t
+						* cylinder_context, int i,
+						int n,
+						float relative_text_width,
+						float *right_point_x,
+						float *right_point_y)
+{
+  GLfloat feedback_buffer[FEEDBACK_BUFFER_SIZE];
+  GLfloat *ptr;
+  float x, y, x_min = 0, x_max = 0, y_min = 0, y_max = 0;
+
+  memset (feedback_buffer, 0, sizeof (GLfloat) * FEEDBACK_BUFFER_SIZE);
+
+  glFeedbackBuffer (FEEDBACK_BUFFER_SIZE, GL_2D, (float *) feedback_buffer);
+
+  mod_gl_utils_set_render_mode_3d_feedback (utils_context);
+  glRenderMode (GL_FEEDBACK);	// enter feedback mode
+
+  _mod_gl_menu_cylinder_draw_cylinder_corners (utils_context,
+					       cylinder_context, i, n,
+					       relative_text_width,
+					       _PASS_THROUGH_SELECTED);
+
+  glRenderMode (GL_RENDER);	// back to normal mode
+
+  ptr = feedback_buffer;
+
+  while ((*ptr) == GL_PASS_THROUGH_TOKEN
+	 && (ptr < feedback_buffer + FEEDBACK_BUFFER_SIZE))
+    {
+      ptr++;
+      if (ptr < feedback_buffer + FEEDBACK_BUFFER_SIZE)
+	{
+	  x_min = utils_context->video_mode.width + 1;
+	  x_max = -1;
+	  y_min = utils_context->video_mode.height + 1;
+	  y_max = -1;
+	  ptr++;		// skipping passthrough value (_PASS_THROUGH_SELECTED)
+	  while ((*ptr) == GL_POINT_TOKEN
+		 && ptr < feedback_buffer + FEEDBACK_BUFFER_SIZE - 3)
+	    {
+	      ptr++;
+	      x = *(ptr++);
+	      y = (utils_context->video_mode.height - *(ptr++));
+	      if (x < x_min)
+		{
+		  x_min = x;
+		}
+	      if (x > x_max)
+		{
+		  x_max = x;
+		}
+	      if (y < y_min)
+		{
+		  y_min = y;
+		}
+	      if (y > y_max)
+		{
+		  y_max = y;
+		}
+	    }
+	}
+    }
+
+  (*right_point_x) = x_max;
+  (*right_point_y) = (y_min + y_max) / 2;
+}
