@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ mod_gl_menu_create_backend (mod_gl_utils_context_t * utils_context,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("menu backend \"%s\" does not exists"), name);
+		  _x_ ("menu backend \"%s\" does not exists"), name);
     }
 
   if (init_func)
