@@ -319,9 +319,10 @@ mod_gl_utils_update_game_bitmap_array (mod_gl_utils_context_t *
 				       lw6ker_game_state_t * game_state,
 				       lw6gui_look_t * look)
 {
-  int n_x, n_y;
+  int i;
   GLint wrap = 0;
   GLint filter = 0;
+  mod_gl_utils_bitmap_t *bitmap = NULL;
 
   if (utils_context->last_action.game_bitmap_array_update_id !=
       game_state->id
@@ -342,18 +343,33 @@ mod_gl_utils_update_game_bitmap_array (mod_gl_utils_context_t *
       utils_context->last_action.game_bitmap_array_update_rounds =
 	lw6ker_game_state_get_rounds (game_state);
 
-      for (n_y = 0; n_y < bitmap_array->layout.n_h; ++n_y)
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("updating %d game tiles"),
+		  bitmap_array->layout.nb_tiles);
+      /*
+       * Typically parallelizable function. Doesn't matter how tiles are updated,
+       * and in which order.
+       */
+#ifdef LW6_OPENMP
+#pragma omp parallel for
+#endif
+      for (i = 0; i < bitmap_array->layout.nb_tiles; ++i)
 	{
-	  for (n_x = 0; n_x < bitmap_array->layout.n_w; ++n_x)
+	  /*
+	   * rect defined locally inside the loop because of
+	   * parallelizing, each thread must have a copy.
+	   */
+	  lw6gui_rect_t rect;
+
+	  if (lw6gui_rect_array_get_tile_by_i
+	      (&(bitmap_array->layout), &rect, i))
 	    {
-	      _update_game_bitmap (utils_context,
-				   mod_gl_utils_bitmap_array_get
-				   (bitmap_array, n_x, n_y), game_state,
-				   look,
-				   bitmap_array->layout.x0[n_x],
-				   bitmap_array->layout.y0[n_y],
-				   bitmap_array->layout.w[n_x],
-				   bitmap_array->layout.h[n_y]);
+	      bitmap = mod_gl_utils_bitmap_array_get (bitmap_array, i);
+	      if (bitmap)
+		{
+		  _update_game_bitmap (utils_context, bitmap, game_state,
+				       look, rect.x1, rect.y1, rect.w,
+				       rect.h);
+		}
 	    }
 	}
 
