@@ -152,6 +152,38 @@ mod_gl_utils_clear_menucache (mod_gl_utils_context_t * context)
 	  mod_gl_utils_bitmap_free (context, bitmap);
 	}
     }
+  if (menucache_array->tooltip_str)
+    {
+      LW6SYS_FREE (menucache_array->tooltip_str);
+    }
+  if (menucache_array->tooltip_bitmap)
+    {
+      mod_gl_utils_bitmap_free (context, menucache_array->tooltip_bitmap);
+    }
+  if (menucache_array->help_str)
+    {
+      LW6SYS_FREE (menucache_array->help_str);
+    }
+  if (menucache_array->help_bitmap)
+    {
+      mod_gl_utils_bitmap_free (context, menucache_array->help_bitmap);
+    }
+  if (menucache_array->breadcrumbs_str)
+    {
+      LW6SYS_FREE (menucache_array->breadcrumbs_str);
+    }
+  if (menucache_array->breadcrumbs_bitmap)
+    {
+      mod_gl_utils_bitmap_free (context, menucache_array->breadcrumbs_bitmap);
+    }
+  if (menucache_array->popup_str)
+    {
+      LW6SYS_FREE (menucache_array->popup_str);
+    }
+  if (menucache_array->popup_bitmap)
+    {
+      mod_gl_utils_bitmap_free (context, menucache_array->popup_bitmap);
+    }
 
   memset (menucache_array, 0, sizeof (mod_gl_utils_menucache_array_t));
 }
