@@ -158,8 +158,8 @@ _display (void *gfx_context, int mask, lw6gui_look_t * look,
        * drawable will be fully handled.
        */
       mod_gl_utils_smoothers_update (&(mod_gl_context->utils_context));	// to be fixed
-
       _mod_gl_set_backends (mod_gl_context, look);
+      mod_gl_utils_cache_update (&(mod_gl_context->utils_context), look);
 
       mod_gl_utils_prepare_buffer (&(mod_gl_context->utils_context), look);
 
@@ -258,6 +258,13 @@ _display (void *gfx_context, int mask, lw6gui_look_t * look,
 					    mod_gl_context->menu_backend,
 					    look, progress);
 	    }
+	  if ((mask & LW6GUI_DISPLAY_META) && menu)
+	    {
+	      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("display step=meta"));
+	      mod_gl_menu_display_meta (&(mod_gl_context->utils_context),
+					mod_gl_context->menu_backend, look,
+					menu);
+	    }
 	}
       if ((mask & LW6GUI_DISPLAY_LOG) && log_list)
 	{
@@ -283,7 +290,7 @@ _display (void *gfx_context, int mask, lw6gui_look_t * look,
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("display step=url"));
 	  mod_gl_utils_display_url (&(mod_gl_context->utils_context),
-				    look, lw6sys_build_get_url ());
+				    look, lw6sys_build_get_home_url ());
 	}
       mod_gl_utils_show_mouse (&(mod_gl_context->utils_context),
 			       mask & LW6GUI_DISPLAY_MOUSE, 0);
