@@ -40,6 +40,10 @@ static u_int32_t seq_id = 0;
  *
  * @title: the string to be displayed, what the user sees. Can be freed after
  *   the call is done, function will make a copy internally.
+ * @help: a string introducing the menu, describing what it does,
+ *   giving hints on how to use it.
+ * @popup: a string to be displayed in popup mode when menu is displayed
+ *   for the first time.
  * @esc: the label to be displayed in the ESC button
  * @enable_esc: wether to enable the escape button.
  *
@@ -49,35 +53,43 @@ static u_int32_t seq_id = 0;
  * Return value: a pointer to the newly allocated object.
  */
 lw6gui_menu_t *
-lw6gui_menu_new (char *title, char *esc, int enable_esc)
+lw6gui_menu_new (char *title, char *help, char *popup, char *esc,
+		 int enable_esc)
 {
   lw6gui_menu_t *menu = NULL;
 
   menu = (lw6gui_menu_t *) LW6SYS_CALLOC (sizeof (lw6gui_menu_t));
   if (menu)
     {
-      menu->title = lw6sys_str_copy (title);
+      menu->id = 0;
+      while (!menu->id)
+	{
+	  menu->id = ++seq_id;
+	}
+
+      menu->title = lw6sys_str_copy (lw6sys_str_empty_if_null (title));
       if (menu->title)
 	{
-	  menu->esc_item = lw6gui_menuitem_new (esc, 0, enable_esc, 0, 0);
-	  if (menu->esc_item)
+	  menu->help = lw6sys_str_copy (lw6sys_str_empty_if_null (help));
+	  if (menu->help)
 	    {
-	      menu->id = 0;
-	      while (!menu->id)
+	      menu->popup =
+		lw6sys_str_copy (lw6sys_str_empty_if_null (popup));
+	      if (menu->popup)
 		{
-		  menu->id = ++seq_id;
+		  menu->esc_item =
+		    lw6gui_menuitem_new (esc, NULL, 0, enable_esc, 0, 0);
+		  if (menu->esc_item)
+		    {
+		      // OK
+		    }
 		}
 	    }
-	  else
-	    {
-	      LW6SYS_FREE (menu->title);
-	      LW6SYS_FREE (menu);
-	      menu = NULL;
-	    }
 	}
-      else
+      if ((!menu->title) || (!menu->help) || (!menu->popup)
+	  || (!menu->esc_item))
 	{
-	  LW6SYS_FREE (menu);
+	  lw6gui_menu_free (menu);
 	  menu = NULL;
 	}
     }
@@ -111,6 +123,26 @@ lw6gui_menu_free (lw6gui_menu_t * menu)
 	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menu with NULL title"));
 	}
 
+      if (menu->help)
+	{
+	  LW6SYS_FREE (menu->help);
+	  menu->help = NULL;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menu with NULL help"));
+	}
+
+      if (menu->popup)
+	{
+	  LW6SYS_FREE (menu->popup);
+	  menu->popup = NULL;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menu with NULL popup"));
+	}
+
       if (menu->esc_item)
 	{
 	  lw6gui_menuitem_free (menu->esc_item);
@@ -123,6 +155,10 @@ lw6gui_menu_free (lw6gui_menu_t * menu)
 	    }
 	  LW6SYS_FREE (menu->items);
 	}
+      if (menu->breadcrumbs)
+	{
+	  lw6sys_list_free (menu->breadcrumbs);
+	}
       LW6SYS_FREE (menu);
     }
   else
@@ -151,6 +187,8 @@ lw6gui_menu_memory_footprint (lw6gui_menu_t * menu)
     {
       memory_footprint += sizeof (lw6gui_menu_t);
       memory_footprint += strlen (menu->title) + 1;
+      memory_footprint += strlen (menu->help) + 1;
+      memory_footprint += strlen (menu->popup) + 1;
       for (i = 0; i < menu->nb_items; ++i)
 	{
 	  memory_footprint +=
@@ -197,7 +235,7 @@ lw6gui_menu_repr (lw6gui_menu_t * menu)
  * @title: the new title, you can free it after calling the function,
  *   an internal copy will be made. 
  *
- * Change the title of the menu. That is to say, its title.
+ * Change the title of the menu.
  * Use this function to change the title, don't try to access the 
  * struct directly. The idea is to have safe memory management.
  *
@@ -207,7 +245,7 @@ void
 lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title)
 {
   LW6SYS_FREE (menu->title);
-  menu->title = lw6sys_str_copy (title);
+  menu->title = lw6sys_str_copy (lw6sys_str_empty_if_null (title));
   if (!(menu->title))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
@@ -215,6 +253,92 @@ lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title)
     }
 }
 
+/**
+ * lw6gui_menu_set_help
+ *
+ * @menu: a pointer to the menu.
+ * @help: the new help, you can free it after calling the function,
+ *   an internal copy will be made. 
+ *
+ * Change the help of the menu.
+ * Use this function to change the help, don't try to access the 
+ * struct directly. The idea is to have safe memory management.
+ *
+ * Return value: none
+ */
+void
+lw6gui_menu_set_help (lw6gui_menu_t * menu, char *help)
+{
+  LW6SYS_FREE (menu->help);
+  menu->help = lw6sys_str_copy (lw6sys_str_empty_if_null (help));
+  if (!(menu->help))
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("couldn't set menu help \"%s\""), help);
+    }
+}
+
+/**
+ * lw6gui_menu_set_popup
+ *
+ * @menu: a pointer to the menu.
+ * @popup: the new popup, you can free it after calling the function,
+ *   an internal copy will be made. 
+ *
+ * Change the popup of the menu. That is to say, its popup.
+ * Use this function to change the popup, don't try to access the 
+ * struct directly. The idea is to have safe memory management.
+ *
+ * Return value: none
+ */
+void
+lw6gui_menu_set_popup (lw6gui_menu_t * menu, char *popup)
+{
+  LW6SYS_FREE (menu->popup);
+  menu->popup = lw6sys_str_copy (lw6sys_str_empty_if_null (popup));
+  if (!(menu->popup))
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("couldn't set menu popup \"%s\""), popup);
+    }
+}
+
+/**
+ * lw6gui_menu_close_popup
+ *
+ * @menu: a pointer to the menu.
+ *
+ * Closes the popup, in practice, this is equivalent to
+ * setting the popup string to "" or NULL.
+ *
+ * Return value: none
+ */
+void
+lw6gui_menu_close_popup (lw6gui_menu_t * menu)
+{
+  lw6gui_menu_set_popup (menu, NULL);
+}
+
+/**
+ * lw6gui_menu_has_popup
+ *
+ * @menu: a pointer to the menu.
+ *
+ * Tells wether a popup is defined. Behavior is simplistic,
+ * at creation (when a non-NULL non-empty popup string has
+ * been set) then the popup is displayed. In this state,
+ * popup is considered to be defined. Then it can be close,
+ * and after this action the popup ain't here anymore,
+ * program continues the way it started.
+ *
+ * Return value: 1 if has popup, 0 if does not
+ */
+int
+lw6gui_menu_has_popup (lw6gui_menu_t * menu)
+{
+  return !lw6sys_str_is_null_or_empty (menu->popup);
+}
+
 /**
  * lw6gui_menu_get_item
  *
@@ -375,6 +499,35 @@ lw6gui_menu_scroll_down (lw6gui_menu_t * menu)
   return ret;
 }
 
+/**
+ * lw6gui_menu_set_breadcrumbs
+ *
+ * @menu: the menu to scroll
+ * @breadcrumbs: list of strings containing breadcrumbs
+ *
+ * Set the breadcrumbs, that's to say the readable, logical
+ * path to get to a given menu. This is just eye candy, not
+ * linked to any logic at this level.
+ *
+ * Return value: 1 if OK, 0 if failed.
+ */
+int
+lw6gui_menu_set_breadcrumbs (lw6gui_menu_t * menu,
+			     lw6sys_list_t * breadcrumbs)
+{
+  int ret = 0;
+
+  if (menu->breadcrumbs)
+    {
+      lw6sys_list_free (menu->breadcrumbs);
+    }
+  menu->breadcrumbs =
+    lw6sys_list_dup (breadcrumbs, (lw6sys_dup_func_t) lw6sys_str_copy);
+  ret = (menu->breadcrumbs != NULL);
+
+  return ret;
+}
+
 /**
  * lw6gui_menu_center
  *
@@ -634,6 +787,7 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
  *
  * @menu: the menu to work on
  * @label: the label of the menuitem to append
+ * @tooltip: the tooltip of the menuitem to append
  * @value: the value of the menuitem to append
  * @enabled: wether the inserted menuitem should be enabled
  * @selected: wether the inserted menuitem should be selected
@@ -656,14 +810,16 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
  *   used with '_using_id' functions.
  */
 int
-lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
-			       int enabled, int selected,
-			       int colored, int position, int64_t now)
+lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label,
+			       char *tooltip, int value, int enabled,
+			       int selected, int colored, int position,
+			       int64_t now)
 {
   int ret = 0;
   lw6gui_menuitem_t *menuitem;
 
-  menuitem = lw6gui_menuitem_new (label, value, enabled, selected, colored);
+  menuitem =
+    lw6gui_menuitem_new (label, tooltip, value, enabled, selected, colored);
   if (menuitem)
     {
       if (lw6gui_menu_insert (menu, menuitem, position, now))
@@ -684,6 +840,7 @@ lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
  *
  * @menu: the menu to work on
  * @label: the label of the menuitem to append
+ * @tooltip: the tooltip of the menuitem to append
  * @value: the value of the menuitem to append
  * @enabled: wether the appended menuitem should be enabled
  * @selected: wether the appended menuitem should be selected
@@ -699,15 +856,15 @@ lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label, int value,
  *   used with '_using_id' functions.
  */
 int
-lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label, int value,
-			       int enabled, int selected,
-			       int colored, int64_t now)
+lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label,
+			       char *tooltip, int value, int enabled,
+			       int selected, int colored, int64_t now)
 {
   int ret = 0;
 
   ret =
-    lw6gui_menu_insert_for_id_use (menu, label, value, enabled, selected,
-				   colored, menu->nb_items, now);
+    lw6gui_menu_insert_for_id_use (menu, label, tooltip, value, enabled,
+				   selected, colored, menu->nb_items, now);
 
   return ret;
 }
@@ -772,6 +929,12 @@ lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id,
  *
  * @menu: the menu to work on
  * @menuitem_id: the id of the menuitem to synchronize
+ * @label: menu label
+ * @tooltip: menu tooltip
+ * @value: value
+ * @enabled: wether it's usable or not
+ * @selected: 1 if the menuite is current item
+ * @colored: wether to use color
  * @now: current time (timestamp)
  *
  * Updates the menuitem with the given id. Very important: the id is not
@@ -786,8 +949,8 @@ lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id,
  */
 void
 lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id, char *label,
-			   int value, int enabled, int selected, int colored,
-			   int64_t now)
+			   char *tooltip, int value, int enabled,
+			   int selected, int colored, int64_t now)
 {
   int position;
   lw6gui_menuitem_t *menuitem;
@@ -799,6 +962,7 @@ lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id, char *label,
       if (menuitem)
 	{
 	  lw6gui_menuitem_set_label (menuitem, label, now);
+	  lw6gui_menuitem_set_tooltip (menuitem, tooltip, now);
 	  lw6gui_menuitem_set_value (menuitem, value, now);
 	  menuitem->enabled = enabled;
 	  if (selected)
@@ -832,7 +996,9 @@ lw6gui_menu_is_same (lw6gui_menu_t * menu_a, lw6gui_menu_t * menu_b)
     }
   if (menu_a && menu_b)
     {
-      ret = ret && !strcmp (menu_a->title, menu_b->title);
+      ret = ret && lw6sys_str_is_same (menu_a->title, menu_b->title);
+      ret = ret && lw6sys_str_is_same (menu_a->help, menu_b->help);
+      ret = ret && lw6sys_str_is_same (menu_a->popup, menu_b->popup);
       ret = ret && menu_a->nb_items == menu_b->nb_items;
       ret = ret
 	&& lw6gui_menuitem_is_same (menu_a->esc_item, menu_b->esc_item);
@@ -854,6 +1020,21 @@ lw6gui_menu_is_same (lw6gui_menu_t * menu_a, lw6gui_menu_t * menu_b)
 	&& menu_a->order_of_selected_on_display ==
 	menu_b->order_of_selected_on_display;
       ret = ret && menu_a->allow_scroll == menu_b->allow_scroll;
+      if (menu_a->breadcrumbs && menu_b->breadcrumbs)
+	{
+	  /*
+	   * OK, here, in theory, we should check each item
+	   * one by one. In practice, we just rely on size,
+	   * period.
+	   */
+	  ret = ret
+	    && lw6sys_list_length (menu_a->breadcrumbs) ==
+	    lw6sys_list_length (menu_b->breadcrumbs);
+	}
+      else
+	{
+	  ret = ret && (menu_a->breadcrumbs == menu_b->breadcrumbs);
+	}
     }
 
   return ret;
@@ -878,8 +1059,8 @@ lw6gui_menu_dup (lw6gui_menu_t * menu)
   if (menu)
     {
       ret =
-	lw6gui_menu_new (menu->title, menu->esc_item->label,
-			 menu->esc_item->enabled);
+	lw6gui_menu_new (menu->title, menu->help, menu->popup,
+			 menu->esc_item->label, menu->esc_item->enabled);
       if (ret)
 	{
 	  lw6gui_menuitem_sync (ret->esc_item, menu->esc_item);
@@ -913,6 +1094,18 @@ lw6gui_menu_dup (lw6gui_menu_t * menu)
       ret->nb_items_displayed = menu->nb_items_displayed;
       ret->order_of_selected_on_display = menu->order_of_selected_on_display;
       ret->allow_scroll = menu->allow_scroll;
+
+      if (menu->breadcrumbs)
+	{
+	  ret->breadcrumbs =
+	    lw6sys_list_dup (menu->breadcrumbs,
+			     (lw6sys_dup_func_t) lw6sys_str_copy);
+	  if (!(ret->breadcrumbs))
+	    {
+	      lw6gui_menu_free (ret);
+	      ret = NULL;
+	    }
+	}
     }
 
   return ret;
@@ -943,10 +1136,18 @@ lw6gui_menu_sync (lw6gui_menu_t * dst, lw6gui_menu_t * src)
 
   if (dst && src)
     {
-      if (strcmp (dst->title, src->title))
+      if (!lw6sys_str_is_same (dst->title, src->title))
 	{
 	  lw6gui_menu_set_title (dst, src->title);
 	}
+      if (!lw6sys_str_is_same (dst->help, src->help))
+	{
+	  lw6gui_menu_set_help (dst, src->help);
+	}
+      if (!lw6sys_str_is_same (dst->popup, src->popup))
+	{
+	  lw6gui_menu_set_popup (dst, src->popup);
+	}
       d = dst->nb_items - src->nb_items;
       if (d > 0)
 	{
@@ -994,6 +1195,39 @@ lw6gui_menu_sync (lw6gui_menu_t * dst, lw6gui_menu_t * src)
 	   * The rest is "normal", copied from src to dst
 	   */
 	  dst->allow_scroll = src->allow_scroll;
+
+	  if (src->breadcrumbs)
+	    {
+	      if (dst->breadcrumbs)
+		{
+		  /*
+		   * Lazy test on size only
+		   */
+		  if (lw6sys_list_length (dst->breadcrumbs) !=
+		      lw6sys_list_length (src->breadcrumbs))
+		    {
+		      lw6sys_list_free (dst->breadcrumbs);
+		      dst->breadcrumbs =
+			lw6sys_list_dup (src->breadcrumbs,
+					 (lw6sys_dup_func_t) lw6sys_str_copy);
+		    }
+		}
+	      else
+		{
+		  dst->breadcrumbs =
+		    lw6sys_list_dup (src->breadcrumbs,
+				     (lw6sys_dup_func_t) lw6sys_str_copy);
+		}
+	    }
+	  else
+	    {
+	      if (dst->breadcrumbs)
+		{
+		  lw6sys_list_free (dst->breadcrumbs);
+		  dst->breadcrumbs = NULL;
+		}
+	    }
+
 	  ret = 1;
 	}
       else
