@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ lw6hlp_about (lw6hlp_type_t * type, char **default_value, int *min_value,
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("keyword '%s' is not documented"),
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("keyword '%s' is not documented"),
 		  keyword);
       if (type)
 	{
@@ -127,7 +127,7 @@ lw6hlp_about (lw6hlp_type_t * type, char **default_value, int *min_value,
 	{
 	  *max_value = 0;
 	}
-      ret = _("Not documented.");
+      ret = _x_ ("Not documented.");
     }
 
   return ret;
