@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "ker-internal.h"
 
 int
-_lw6ker_armies_init (lw6ker_armies_t * armies,
-		     lw6ker_map_struct_t * map_struct,
+_lw6ker_armies_init (_lw6ker_armies_t * armies,
+		     _lw6ker_map_struct_t * map_struct,
 		     lw6map_rules_t * options)
 {
   int ret = 0;
@@ -50,14 +50,14 @@ _lw6ker_armies_init (lw6ker_armies_t * armies,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to allocate armies"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to allocate armies"));
     }
 
   return ret;
 }
 
 void
-_lw6ker_armies_clear (lw6ker_armies_t * armies)
+_lw6ker_armies_clear (_lw6ker_armies_t * armies)
 {
   if (armies->fighters)
     {
@@ -70,7 +70,7 @@ _lw6ker_armies_clear (lw6ker_armies_t * armies)
 }
 
 int
-_lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src)
+_lw6ker_armies_sync (_lw6ker_armies_t * dst, _lw6ker_armies_t * src)
 {
   int ret = 0;
 
@@ -93,7 +93,7 @@ _lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("armies_copy only works if dst and src point to the same map_struct"));
     }
 
@@ -101,7 +101,7 @@ _lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src)
 }
 
 void
-_lw6ker_armies_update_checksum (lw6ker_armies_t * armies,
+_lw6ker_armies_update_checksum (_lw6ker_armies_t * armies,
 				u_int32_t * checksum)
 {
   int i;
@@ -120,7 +120,8 @@ _lw6ker_armies_update_checksum (lw6ker_armies_t * armies,
 }
 
 int32_t
-lw6ker_armies_add_fighter (lw6ker_armies_t * armies, lw6ker_fighter_t fighter)
+_lw6ker_armies_add_fighter (_lw6ker_armies_t * armies,
+			    lw6ker_fighter_t fighter)
 {
   int32_t new_id = -1;
 
@@ -134,7 +135,7 @@ lw6ker_armies_add_fighter (lw6ker_armies_t * armies, lw6ker_fighter_t fighter)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("unable to add fighter, there are already %d fighters"),
 		  armies->active_fighters);
     }
@@ -148,7 +149,7 @@ lw6ker_armies_add_fighter (lw6ker_armies_t * armies, lw6ker_fighter_t fighter)
  * then delete.
  */
 int
-lw6ker_armies_remove_fighter (lw6ker_armies_t * armies)
+_lw6ker_armies_remove_fighter (_lw6ker_armies_t * armies)
 {
   int ret = 0;
 
@@ -173,7 +174,7 @@ lw6ker_armies_remove_fighter (lw6ker_armies_t * armies)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to remove fighter, none to remove"));
+		  _x_ ("unable to remove fighter, none to remove"));
     }
 
   return ret;
