@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_place_struct_update_checksum (lw6ker_place_struct_t * place_struct,
+_lw6ker_place_struct_update_checksum (_lw6ker_place_struct_t * place_struct,
 				      u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, place_struct->act_incr);
