@@ -32,11 +32,11 @@
  * and calculating "what's in that direction?".
  */
 _lw6ker_tables_move_offset_t _LW6KER_TABLES_MOVE_X_OFFSET =
-  { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0, 0, 0 };
+  { 1, 1, 1, 0, 0, -1, -1, -1, -1, 0, 0, 1, 0, 0 };
 _lw6ker_tables_move_offset_t _LW6KER_TABLES_MOVE_Y_OFFSET =
-  { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1, 0, 0 };
+  { 0, 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0, 0 };
 _lw6ker_tables_move_offset_t _LW6KER_TABLES_MOVE_Z_OFFSET =
-  { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1 };
+  { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1 };
 
 /*
  * Used to try a direction or another one, when something
@@ -44,14 +44,6 @@ _lw6ker_tables_move_offset_t _LW6KER_TABLES_MOVE_Z_OFFSET =
  */
 _lw6ker_tables_move_dir_t _LW6KER_TABLES_MOVE_DIR = {
   {				// parity 0
-   {
-    LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_NW, LW6KER_DIR_ENE,
-    LW6KER_DIR_WNW, LW6KER_DIR_SE, LW6KER_DIR_SW}
-   ,
-   {
-    LW6KER_DIR_NE, LW6KER_DIR_ENE, LW6KER_DIR_NNE, LW6KER_DIR_SE,
-    LW6KER_DIR_NW, LW6KER_DIR_SSE, LW6KER_DIR_WNW}
-   ,
    {
     LW6KER_DIR_ENE, LW6KER_DIR_NE, LW6KER_DIR_SE, LW6KER_DIR_NNE,
     LW6KER_DIR_SSE, LW6KER_DIR_NW, LW6KER_DIR_SW}
@@ -92,24 +84,24 @@ _lw6ker_tables_move_dir_t _LW6KER_TABLES_MOVE_DIR = {
     LW6KER_DIR_NNW, LW6KER_DIR_NW, LW6KER_DIR_NE, LW6KER_DIR_WNW,
     LW6KER_DIR_ENE, LW6KER_DIR_SW, LW6KER_DIR_SE}
    ,
-   {
-    LW6KER_DIR_UP, LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_ENE,
-    LW6KER_DIR_ESE, LW6KER_DIR_SE, LW6KER_DIR_SSE}
-   ,
-   {
-    LW6KER_DIR_DOWN, LW6KER_DIR_SSW, LW6KER_DIR_SW, LW6KER_DIR_WSW,
-    LW6KER_DIR_WNW, LW6KER_DIR_NW, LW6KER_DIR_NNW}
-   }
-  ,
-  {				// parity 1
    {
     LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_NW, LW6KER_DIR_ENE,
     LW6KER_DIR_WNW, LW6KER_DIR_SE, LW6KER_DIR_SW}
    ,
    {
-    LW6KER_DIR_NE, LW6KER_DIR_NNE, LW6KER_DIR_ENE, LW6KER_DIR_NW,
-    LW6KER_DIR_SE, LW6KER_DIR_WNW, LW6KER_DIR_SSE}
+    LW6KER_DIR_NE, LW6KER_DIR_ENE, LW6KER_DIR_NNE, LW6KER_DIR_SE,
+    LW6KER_DIR_NW, LW6KER_DIR_SSE, LW6KER_DIR_WNW}
    ,
+   {
+    LW6KER_DIR_DOWN, LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_ENE,
+    LW6KER_DIR_ESE, LW6KER_DIR_SE, LW6KER_DIR_SSE}
+   ,
+   {
+    LW6KER_DIR_UP, LW6KER_DIR_SSW, LW6KER_DIR_SW, LW6KER_DIR_WSW,
+    LW6KER_DIR_WNW, LW6KER_DIR_NW, LW6KER_DIR_NNW}
+   }
+  ,
+  {				// parity 1
    {
     LW6KER_DIR_ENE, LW6KER_DIR_NE, LW6KER_DIR_SE, LW6KER_DIR_NNE,
     LW6KER_DIR_SSE, LW6KER_DIR_NW, LW6KER_DIR_SW}
@@ -151,11 +143,19 @@ _lw6ker_tables_move_dir_t _LW6KER_TABLES_MOVE_DIR = {
     LW6KER_DIR_ENE, LW6KER_DIR_SW, LW6KER_DIR_SE}
    ,
    {
-    LW6KER_DIR_UP, LW6KER_DIR_WSW, LW6KER_DIR_SW, LW6KER_DIR_SSW,
+    LW6KER_DIR_NNE, LW6KER_DIR_NE, LW6KER_DIR_NW, LW6KER_DIR_ENE,
+    LW6KER_DIR_WNW, LW6KER_DIR_SE, LW6KER_DIR_SW}
+   ,
+   {
+    LW6KER_DIR_NE, LW6KER_DIR_NNE, LW6KER_DIR_ENE, LW6KER_DIR_NW,
+    LW6KER_DIR_SE, LW6KER_DIR_WNW, LW6KER_DIR_SSE}
+   ,
+   {
+    LW6KER_DIR_DOWN, LW6KER_DIR_WSW, LW6KER_DIR_SW, LW6KER_DIR_SSW,
     LW6KER_DIR_SSE, LW6KER_DIR_SE, LW6KER_DIR_ESE}
    ,
    {
-    LW6KER_DIR_DOWN, LW6KER_DIR_ENE, LW6KER_DIR_NE, LW6KER_DIR_NNE,
+    LW6KER_DIR_UP, LW6KER_DIR_ENE, LW6KER_DIR_NE, LW6KER_DIR_NNE,
     LW6KER_DIR_NNW, LW6KER_DIR_NW, LW6KER_DIR_WNW}
    }
 };
