@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -75,8 +75,8 @@ read_png (lw6map_meta_layer_t * meta_layer, _lw6ldr_image_bw_t * image,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("unable to allocate memory for meta_layer"));
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("unable to allocate memory for meta_layer"));
     }
 
   return ret;
