@@ -181,7 +181,7 @@ test_data_callback_deep (void *func_data, void *data)
   int *ret = (int *) func_data;
   int ok = 0;
 
-  if (entry)
+  if (entry && (!entry->forbidden))
     {
       ok = check_map_with_absolute_path (entry->absolute_path);
       if (ret)
@@ -263,7 +263,7 @@ test_dir ()
 		  {
 		    lw6sys_log (LW6SYS_LOG_NOTICE,
 				_x_ ("found map \"%s\" in \"%s\""),
-				entry->title, entry->absolute_path);
+				entry->metadata.title, entry->absolute_path);
 		    entry_found = 1;
 		    lw6ldr_free_entry (entry);
 		  };
