@@ -145,15 +145,15 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	      ret = lw6sys_test_exec (argc, argv, 1) && lw6sys_test (1)
 		&& lw6glb_test (1)
 		&& lw6map_test (1)
-		&& lw6ker_test (1) && DYN_TEST && lw6bot_test (1)
-		&& lw6cns_test (1)
+		&& lw6ker_test (1) && lw6pil_test (1) && DYN_TEST
+		&& lw6bot_test (1) && lw6sim_test (1) && lw6cns_test (1)
 		&& lw6hlp_test (1) && lw6cfg_test (1) && lw6ldr_test (1)
 		&& lw6tsk_test (1) && lw6gui_test (1) && lw6vox_test (1)
 		&& lw6gfx_test (1) && lw6dsp_test (1) && lw6snd_test (1)
-		&& lw6img_test (1) && lw6pil_test (1) && lw6net_test (1)
-		&& lw6nod_test (1) && lw6cnx_test (1) && lw6msg_test (1)
-		&& lw6cli_test (1) && lw6srv_test (1) && lw6dat_test (1)
-		&& lw6p2p_test (1) && lw6scm_test (1) && lw6_test (1);
+		&& lw6img_test (1) && lw6net_test (1) && lw6nod_test (1)
+		&& lw6cnx_test (1) && lw6msg_test (1) && lw6cli_test (1)
+		&& lw6srv_test (1) && lw6dat_test (1) && lw6p2p_test (1)
+		&& lw6scm_test (1) && lw6_test (1);
 	      if (ret)
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _("all tests SUCCESSFULL!"));
@@ -179,15 +179,15 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	      ret = lw6sys_test_exec (argc, argv, 0) && lw6sys_test (0)
 		&& lw6glb_test (0)
 		&& lw6map_test (0)
-		&& lw6ker_test (0) && DYN_TEST && lw6bot_test (0)
-		&& lw6cns_test (0)
+		&& lw6ker_test (0) && lw6pil_test (0) && DYN_TEST
+		&& lw6bot_test (0) && lw6sim_test (0) && lw6cns_test (0)
 		&& lw6hlp_test (0) && lw6cfg_test (0) && lw6ldr_test (0)
 		&& lw6tsk_test (0) && lw6gui_test (0) && lw6vox_test (0)
 		&& lw6gfx_test (0) && lw6dsp_test (0) && lw6snd_test (0)
-		&& lw6img_test (0) && lw6pil_test (0) && lw6net_test (0)
-		&& lw6nod_test (0) && lw6cnx_test (0) && lw6msg_test (0)
-		&& lw6cli_test (0) && lw6srv_test (0) && lw6dat_test (0)
-		&& lw6p2p_test (0) && lw6scm_test (0) && lw6_test (0);
+		&& lw6img_test (0) && lw6net_test (0) && lw6nod_test (0)
+		&& lw6cnx_test (0) && lw6msg_test (0) && lw6cli_test (0)
+		&& lw6srv_test (0) && lw6dat_test (0) && lw6p2p_test (0)
+		&& lw6scm_test (0) && lw6_test (0);
 	      if (ret)
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -356,6 +356,16 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_list_aliases ();
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_LIST_TEAM_COLORS, argv[i]))
+	{
+	  lw6_print_list_team_colors ();
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_LIST_WEAPONS, argv[i]))
+	{
+	  lw6_print_list_weapons ();
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_EXAMPLE_RULES_XML, argv[i]))
 	{
 	  lw6ldr_print_example_rules_xml (stdout);
@@ -424,9 +434,14 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_license ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_URL, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_HOME_URL, argv[i]))
 	{
-	  printf ("%s\n", lw6sys_build_get_url ());
+	  printf ("%s\n", lw6sys_build_get_home_url ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_BUGS_URL, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_bugs_url ());
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CONFIGURE_ARGS, argv[i])
@@ -492,21 +507,31 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_host_os ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_GNU, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_gnu ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_UNIX, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_unix ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_MS_WINDOWS, argv[i]))
 	{
 	  printf ("%d\n", lw6sys_build_is_ms_windows ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_GP2X, argv[i]))
-	{
-	  printf ("%d\n", lw6sys_build_is_gp2x ());
-	  (*run_game) = 0;
-	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_MAC_OS_X, argv[i]))
 	{
 	  printf ("%d\n", lw6sys_build_is_mac_os_x ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_GP2X, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_gp2x ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TOP_SRCDIR, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_top_srcdir ());
@@ -965,6 +990,25 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	    }
 	  (*run_game) = 0;
 	}
+      /*
+       * Simulate fights for statistics
+       */
+      else if (lw6sys_arg_match (LW6DEF_SIMULATE_BASIC, argv[i]))
+	{
+	  lw6sim_results_t results;
+
+	  lw6sim_simulate_basic (argc, argv, &results);
+	  lw6sim_print (&results, stdout);
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SIMULATE_FULL, argv[i]))
+	{
+	  lw6sim_results_t results;
+
+	  lw6sim_simulate_full (argc, argv, &results);
+	  lw6sim_print (&results, stdout);
+	  (*run_game) = 0;
+	}
     }
 
   return ret;
