@@ -54,11 +54,8 @@ lw6_print_help ()
       lw6sys_list_free (list);
     }
 
-  printf
-    (_("Online manual: http://www.gnu.org/software/liquidwar6/manual/\n"));
-  printf ("\n");
-  printf (_("Report bugs to <bug-liquidwar6@gnu.org>\n"));
-  printf ("\n");
+  printf ("%s: %s\n\n", _("Home page"), lw6sys_build_get_home_url ());
+  printf ("%s: %s\n\n", _("Report bugs"), lw6sys_build_get_bugs_url ());
 
   fflush (stdout);
 }
@@ -163,7 +160,8 @@ lw6_print_pedigree ()
   printf ("md5sum: %s\n", lw6sys_build_get_md5sum ());
   printf ("copyright: %s\n", lw6sys_build_get_copyright ());
   printf ("license: %s\n", lw6sys_build_get_license ());
-  printf ("url: %s\n", lw6sys_build_get_url ());
+  printf ("home url: %s\n", lw6sys_build_get_home_url ());
+  printf ("bugs url: %s\n", lw6sys_build_get_bugs_url ());
   printf ("configure-args: %s\n", lw6sys_build_get_configure_args ());
   printf ("gcc-version: %s\n", lw6sys_build_get_gcc_version ());
   printf ("cflags: %s\n", lw6sys_build_get_cflags ());
@@ -190,6 +188,8 @@ lw6_print_host ()
   printf ("pointer-size: %d\n", lw6sys_build_get_pointer_size ());
   printf ("x86: %d\n", lw6sys_build_is_x86 ());
   printf ("host-os: %s\n", lw6sys_build_get_host_os ());
+  printf ("gnu: %d\n", lw6sys_build_is_gnu ());
+  printf ("unix: %d\n", lw6sys_build_is_unix ());
   printf ("ms-windows: %d\n", lw6sys_build_is_ms_windows ());
   printf ("mac-os-x: %d\n", lw6sys_build_is_mac_os_x ());
   printf ("gp2x: %d\n", lw6sys_build_is_gp2x ());
@@ -802,6 +802,46 @@ lw6_print_list_aliases ()
     }
 }
 
+/**
+ * lw6_print_list_team_colors
+ *
+ * Displays the list of team colors.
+ *
+ * Return value: none
+ */
+void
+lw6_print_list_team_colors ()
+{
+  lw6sys_list_t *list;
+
+  list = lw6hlp_list_team_colors ();
+  if (list)
+    {
+      lw6hlp_print_keyword (&list, stdout);
+      lw6sys_list_free (list);
+    }
+}
+
+/**
+ * lw6_print_list_weapons
+ *
+ * Displays the list of weapons.
+ *
+ * Return value: none
+ */
+void
+lw6_print_list_weapons ()
+{
+  lw6sys_list_t *list;
+
+  list = lw6hlp_list_weapons ();
+  if (list)
+    {
+      lw6hlp_print_keyword (&list, stdout);
+      lw6sys_list_free (list);
+    }
+}
+
 /**
  * lw6_print_list
  *
@@ -845,15 +885,45 @@ lw6_print_about (char *keyword)
 void
 lw6_print_hello (int argc, char *argv[])
 {
+  char *username = NULL;
+  char *hostname = NULL;
+  char *date_rfc1123 = NULL;
+
   lw6sys_log (LW6SYS_LOG_INFO, _("hello"));
 
+  lw6sys_log (LW6SYS_LOG_NOTICE, "v%s \"%s\" #%s (%s) %s/%s",
+	      lw6sys_build_get_version (),
+	      lw6sys_build_get_codename (),
+	      lw6sys_build_get_stamp (),
+	      lw6sys_build_get_date (),
+	      lw6sys_build_get_host_os (), lw6sys_build_get_host_cpu ());
+
+  date_rfc1123 = lw6sys_date_rfc1123 (0);
+  if (date_rfc1123)
+    {
+      username = lw6sys_get_username ();
+      if (username)
+	{
+	  hostname = lw6sys_get_hostname ();
+	  {
+	    lw6sys_log (LW6SYS_LOG_INFO, "%s \"%s@%s\"",
+			date_rfc1123, username, hostname);
+	    LW6SYS_FREE (hostname);
+	  }
+	  LW6SYS_FREE (username);
+	}
+      LW6SYS_FREE (date_rfc1123);
+    }
+
+  lw6sys_log (LW6SYS_LOG_INFO, "%d %s - %d %s",
+	      lw6sys_megabytes_available (), _x_ ("Mb"),
+	      lw6sys_openmp_get_num_procs (), _x_ ("procs"));
+
   lw6sys_build_log_all ();
   lw6sys_options_log_defaults ();
   lw6sys_options_log (argc, argv);
 
   lw6sys_check_types_size (argc, argv);
-  lw6sys_log (LW6SYS_LOG_INFO, _("approx. %d megabytes available"),
-	      lw6sys_megabytes_available ());
 }
 
 /**
