@@ -45,13 +45,16 @@ lw6map_body_builtin_custom (lw6map_body_t * body, int w, int h, int d,
 			    int noise_percent, lw6map_rules_t * rules)
 {
   int layer;
+  lw6sys_whd_t shape_min =
+    { LW6MAP_MIN_BODY_WIDTH, LW6MAP_MIN_BODY_HEIGHT, LW6MAP_MIN_BODY_DEPTH };
+  lw6sys_whd_t shape_max =
+    { LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_BODY_DEPTH };
 
   lw6map_body_clear (body);
   body->shape.w = w;
   body->shape.h = h;
   body->shape.d = d;
-  if (!lw6sys_shape_check_min_max_whd
-      (&body->shape, LW6MAP_MIN_SIDE, LW6MAP_MAX_SIDE, LW6MAP_MAX_DEPTH))
+  if (!lw6sys_shape_check_min_max_whd (&body->shape, &shape_min, &shape_max))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _x_ ("incorrect default map size %dx%dx%d"), body->shape.w,
@@ -95,7 +98,7 @@ lw6map_body_clear (lw6map_body_t * body)
 {
   int layer;
 
-  for (layer = 0; layer < LW6MAP_MAX_DEPTH; ++layer)
+  for (layer = 0; layer < LW6MAP_MAX_BODY_DEPTH; ++layer)
     {
       lw6map_layer_clear (&(body->layers[layer]));
     }
