@@ -25,7 +25,7 @@
 
 #include "pil.h"
 
-#define _LW6PIL_MIN_SEQ_0 10000000000L
+#define _LW6PIL_MIN_SEQ_0 10000000000LL
 #define _LW6PIL_RANGE_SEQ_0 1000000000
 
 typedef struct _lw6pil_pilot_s
