@@ -37,24 +37,11 @@
  */
 static u_int32_t seq_id = 0;
 
-/**
- * lw6pil_pilot_new
- *
- * @game_state: the game state we're going to work on
- * @timestamp: the current ticks (1000 ticks per sec, used to calibrate)
- * @progress: object used to show the advancement of the process
- *
- * Initializes a 'pilot' object, this object is responsible for
- * interpreting messages, transform them into low-level 'ker' module
- * function calls, and handle all the thread-spooky stuff.
- *
- * Return value: a working pilot object. May be NULL on memory failure.
- */
-lw6pil_pilot_t *
-lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t timestamp,
-		  lw6sys_progress_t * progress)
+_lw6pil_pilot_t *
+_lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t seq_0,
+		   int64_t timestamp, lw6sys_progress_t * progress)
 {
-  lw6pil_pilot_t *ret = NULL;
+  _lw6pil_pilot_t *ret = NULL;
   int ok = 0;
   lw6sys_progress_t progress_level;
   lw6sys_progress_t progress_game_struct;
@@ -66,7 +53,7 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t timestamp,
 			  &progress_game_state, &progress_reference,
 			  &progress_draft, progress);
 
-  ret = (lw6pil_pilot_t *) LW6SYS_CALLOC (sizeof (lw6pil_pilot_t));
+  ret = (_lw6pil_pilot_t *) LW6SYS_CALLOC (sizeof (_lw6pil_pilot_t));
   if (ret)
     {
       ret->id = 0;
@@ -74,11 +61,12 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t timestamp,
 	{
 	  ret->id = ++seq_id;
 	}
-      ret->last_commit_round = -1;
-      ret->last_sync_draft_from_reference = -1;
-      lw6pil_pilot_calibrate (ret, timestamp,
-			      lw6ker_game_state_get_rounds (game_state));
-
+      ret->last_commit_seq = -1L;
+      ret->last_sync_draft_from_reference_seq = -1L;
+      ret->seq_0 = seq_0;
+      _lw6pil_pilot_calibrate (ret, timestamp,
+			       seq_0 +
+			       lw6ker_game_state_get_rounds (game_state));
       ret->replay =
 	lw6sys_list_new ((lw6sys_free_func_t) lw6pil_command_free);
       if (ret->replay)
@@ -175,17 +163,29 @@ lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t timestamp,
 }
 
 /**
- * lw6pil_pilot_free
+ * lw6pil_pilot_new
  *
- * @pilot: the object to free.
+ * @game_state: the game state we're going to work on
+ * @seq_0: the start sequence to use, that is, the seq at round=0
+ * @timestamp: the current ticks (1000 ticks per sec, used to calibrate)
+ * @progress: object used to show the advancement of the process
  *
- * Frees a 'pilot' object, note that this might involve joining
- * some threads, so it can 'take some time'.
+ * Initializes a 'pilot' object, this object is responsible for
+ * interpreting messages, transform them into low-level 'ker' module
+ * function calls, and handle all the thread-spooky stuff.
  *
- * Return value: none.
+ * Return value: a working pilot object. May be NULL on memory failure.
  */
+lw6pil_pilot_t *
+lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t seq_0,
+		  int64_t timestamp, lw6sys_progress_t * progress)
+{
+  return (lw6pil_pilot_t *) _lw6pil_pilot_new (game_state, seq_0, timestamp,
+					       progress);
+}
+
 void
-lw6pil_pilot_free (lw6pil_pilot_t * pilot)
+_lw6pil_pilot_free (_lw6pil_pilot_t * pilot)
 {
   if (pilot)
     {
@@ -206,19 +206,24 @@ lw6pil_pilot_free (lw6pil_pilot_t * pilot)
 }
 
 /**
- * lw6pil_pilot_send_command
+ * lw6pil_pilot_free
  *
- * @pilot: the object to send commands to.
- * @command_text: the text of the command, as received form network
- * @verified: wether we're sure this message is valid.
+ * @pilot: the object to free.
  *
- * Sends a command and handles it internally.
+ * Frees a 'pilot' object, note that this might involve joining
+ * some threads, so it can 'take some time'.
  *
- * Return value: 1 if OK, 0 if not.
+ * Return value: none.
  */
+void
+lw6pil_pilot_free (lw6pil_pilot_t * pilot)
+{
+  _lw6pil_pilot_free ((_lw6pil_pilot_t *) pilot);
+}
+
 int
-lw6pil_pilot_send_command (lw6pil_pilot_t * pilot, char *command_text,
-			   int verified)
+_lw6pil_pilot_send_command (_lw6pil_pilot_t * pilot, char *command_text,
+			    int verified)
 {
   int ret = 1;
   char *command_text_dup;
@@ -240,6 +245,36 @@ lw6pil_pilot_send_command (lw6pil_pilot_t * pilot, char *command_text,
   return ret;
 }
 
+/**
+ * lw6pil_pilot_send_command
+ *
+ * @pilot: the object to send commands to.
+ * @command_text: the text of the command, as received form network
+ * @verified: wether we're sure this message is valid.
+ *
+ * Sends a command and handles it internally.
+ *
+ * Return value: 1 if OK, 0 if not.
+ */
+int
+lw6pil_pilot_send_command (lw6pil_pilot_t * pilot, char *command_text,
+			   int verified)
+{
+  return _lw6pil_pilot_send_command ((_lw6pil_pilot_t *) pilot, command_text,
+				     verified);
+}
+
+int
+_lw6pil_pilot_local_command (_lw6pil_pilot_t * pilot, char *command_text)
+{
+  int ret = 0;
+
+  ret =
+    lw6pil_command_execute_local_text (&(pilot->local_cursors), command_text);
+
+  return ret;
+}
+
 /**
  * lw6pil_pilot_local_command
  *
@@ -261,25 +296,21 @@ lw6pil_pilot_send_command (lw6pil_pilot_t * pilot, char *command_text,
 int
 lw6pil_pilot_local_command (lw6pil_pilot_t * pilot, char *command_text)
 {
-  int ret = 0;
-
-  ret =
-    lw6pil_command_execute_local_text (&(pilot->local_cursors), command_text);
-
-  return ret;
+  return _lw6pil_pilot_local_command ((_lw6pil_pilot_t *) pilot,
+				      command_text);
 }
 
 static void
-sync_draft_from_reference (lw6pil_pilot_t * pilot)
+sync_draft_from_reference (_lw6pil_pilot_t * pilot)
 {
-  if (lw6pil_pilot_get_reference_current_round (pilot) >
-      pilot->last_sync_draft_from_reference)
+  if (_lw6pil_pilot_get_reference_current_seq (pilot) >
+      pilot->last_sync_draft_from_reference_seq)
     {
       lw6sys_mutex_lock (pilot->draft.compute_mutex);
       lw6sys_mutex_lock (pilot->reference.compute_mutex);
 
-      if (lw6pil_pilot_get_reference_current_round (pilot) >
-	  pilot->last_sync_draft_from_reference)
+      if (_lw6pil_pilot_get_reference_current_seq (pilot) >
+	  pilot->last_sync_draft_from_reference_seq)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("pilot sync round=%d"),
 		      lw6ker_game_state_get_rounds (pilot->
@@ -289,8 +320,8 @@ sync_draft_from_reference (lw6pil_pilot_t * pilot)
 	  pilot->draft.target_round = pilot->reference.target_round;
 	  pilot->draft.current_round = pilot->reference.current_round;
 
-	  pilot->last_sync_draft_from_reference =
-	    lw6pil_pilot_get_reference_current_round (pilot);
+	  pilot->last_sync_draft_from_reference_seq =
+	    _lw6pil_pilot_get_reference_current_seq (pilot);
 	}
 
       lw6sys_mutex_unlock (pilot->reference.compute_mutex);
@@ -299,13 +330,14 @@ sync_draft_from_reference (lw6pil_pilot_t * pilot)
 }
 
 static int
-commit_reference (lw6pil_pilot_t * pilot)
+_commit_reference (_lw6pil_pilot_t * pilot)
 {
   int ret = 1;
   char *command_text = NULL;
   lw6pil_command_t *command = NULL;
   int min_round = -1;
   int max_round = 0;
+  int last_commit_round = 0;
 
   /*
    * Process the commands for the reference threads.
@@ -317,7 +349,7 @@ commit_reference (lw6pil_pilot_t * pilot)
 	     && (command_text =
 		 lw6sys_list_pop_front (&(pilot->verified_queue))) != NULL)
 	{
-	  command = lw6pil_command_new (command_text);
+	  command = lw6pil_command_new (command_text, pilot->seq_0);
 	  if (command)
 	    {
 	      if (min_round < 0)
@@ -342,17 +374,22 @@ commit_reference (lw6pil_pilot_t * pilot)
       lw6sys_spinlock_unlock (pilot->reference.commands_spinlock);
       if (min_round >= 0)
 	{
-	  if (min_round <= pilot->last_commit_round)
+	  last_commit_round =
+	    _lw6pil_pilot_seq2round (pilot, pilot->last_commit_seq);
+	  if (min_round <= last_commit_round)
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _x_
-			  ("possible game inconsistency, min_round=%d last_commit_round=%d"),
-			  min_round, pilot->last_commit_round);
+			  ("possible game inconsistency, min_round=%d last_commit_round=%d, seq_0=%"
+			   LW6SYS_PRINTF_LL "d last_commmit_seq=%"
+			   LW6SYS_PRINTF_LL "d"), min_round,
+			  last_commit_round, pilot->seq_0,
+			  pilot->last_commit_seq);
 	    }
 	}
       if (max_round > 0)
 	{
-	  pilot->last_commit_round = max_round;
+	  pilot->last_commit_seq = _lw6pil_pilot_round2seq (pilot, max_round);
 	}
     }
 
@@ -360,13 +397,14 @@ commit_reference (lw6pil_pilot_t * pilot)
 }
 
 static int
-commit_draft (lw6pil_pilot_t * pilot)
+_commit_draft (_lw6pil_pilot_t * pilot)
 {
   int ret = 1;
   char *command_text = NULL;
   lw6pil_command_t *command = NULL;
   lw6pil_command_t *command_dup = NULL;
   lw6sys_list_t *replay = NULL;
+  int last_sync_draft_from_reference = 0;
 
   /*
    * Process the commands for the draft threads.
@@ -380,10 +418,13 @@ commit_draft (lw6pil_pilot_t * pilot)
 	     && (command_text =
 		 lw6sys_list_pop_front (&(pilot->unverified_queue))) != NULL)
 	{
-	  command = lw6pil_command_new (command_text);
+	  command = lw6pil_command_new (command_text, pilot->seq_0);
 	  if (command)
 	    {
-	      if (command->round > pilot->last_sync_draft_from_reference
+	      last_sync_draft_from_reference =
+		_lw6pil_pilot_seq2round (pilot,
+					 pilot->last_sync_draft_from_reference_seq);
+	      if (command->round > last_sync_draft_from_reference
 		  && pilot->replay)
 		{
 		  lw6sys_list_push_front (&(pilot->replay), command);
@@ -421,7 +462,10 @@ commit_draft (lw6pil_pilot_t * pilot)
 			 (lw6pil_command_t *)
 			 lw6sys_list_pop_front (&(pilot->replay))))
 		{
-		  if (command->round > pilot->last_sync_draft_from_reference)
+		  last_sync_draft_from_reference =
+		    _lw6pil_pilot_seq2round (pilot,
+					     pilot->last_sync_draft_from_reference_seq);
+		  if (command->round > last_sync_draft_from_reference)
 		    {
 		      command_dup = lw6pil_command_dup (command);
 		      if (command_dup)
@@ -454,6 +498,17 @@ commit_draft (lw6pil_pilot_t * pilot)
   return ret;
 }
 
+int
+_lw6pil_pilot_commit (_lw6pil_pilot_t * pilot)
+{
+  int ret = 1;
+
+  ret = _commit_reference (pilot) && ret;
+  ret = _commit_draft (pilot) && ret;
+
+  return ret;
+}
+
 /**
  * lw6pil_pilot_commit
  *
@@ -468,10 +523,15 @@ commit_draft (lw6pil_pilot_t * pilot)
 int
 lw6pil_pilot_commit (lw6pil_pilot_t * pilot)
 {
-  int ret = 1;
+  return _lw6pil_pilot_commit ((_lw6pil_pilot_t *) pilot);
+}
 
-  ret = commit_reference (pilot) && ret;
-  ret = commit_draft (pilot) && ret;
+int
+_lw6pil_pilot_make_backup (_lw6pil_pilot_t * pilot)
+{
+  int ret = 0;
+
+  ret = _lw6pil_pilot_sync_from_reference (pilot->backup, pilot);
 
   return ret;
 }
@@ -489,9 +549,18 @@ lw6pil_pilot_commit (lw6pil_pilot_t * pilot)
 int
 lw6pil_pilot_make_backup (lw6pil_pilot_t * pilot)
 {
-  int ret = 0;
+  return _lw6pil_pilot_make_backup ((_lw6pil_pilot_t *) pilot);
+}
 
-  ret = lw6pil_pilot_sync_from_reference (pilot->backup, pilot);
+int
+_lw6pil_pilot_can_sync (lw6ker_game_state_t * target, _lw6pil_pilot_t * pilot)
+{
+  int ret = 1;
+
+  ret = ret && lw6ker_game_state_can_sync (target, pilot->backup);
+  ret = ret
+    && lw6ker_game_state_can_sync (target, pilot->reference.game_state);
+  ret = ret && lw6ker_game_state_can_sync (target, pilot->draft.game_state);
 
   return ret;
 }
@@ -510,12 +579,18 @@ lw6pil_pilot_make_backup (lw6pil_pilot_t * pilot)
 int
 lw6pil_pilot_can_sync (lw6ker_game_state_t * target, lw6pil_pilot_t * pilot)
 {
-  int ret = 1;
+  return _lw6pil_pilot_can_sync (target, (_lw6pil_pilot_t *) pilot);
+}
 
-  ret = ret && lw6ker_game_state_can_sync (target, pilot->backup);
-  ret = ret
-    && lw6ker_game_state_can_sync (target, pilot->reference.game_state);
-  ret = ret && lw6ker_game_state_can_sync (target, pilot->draft.game_state);
+int
+_lw6pil_pilot_sync_from_backup (lw6ker_game_state_t * target,
+				_lw6pil_pilot_t * pilot)
+{
+  int ret = 0;
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("sync from backup round=%d"),
+	      lw6ker_game_state_get_rounds (pilot->backup));
+  ret = lw6ker_game_state_sync (target, pilot->backup);
 
   return ret;
 }
@@ -535,12 +610,23 @@ lw6pil_pilot_can_sync (lw6ker_game_state_t * target, lw6pil_pilot_t * pilot)
 int
 lw6pil_pilot_sync_from_backup (lw6ker_game_state_t * target,
 			       lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_sync_from_backup (target, (_lw6pil_pilot_t *) pilot);
+}
+
+int
+_lw6pil_pilot_sync_from_reference (lw6ker_game_state_t * target,
+				   _lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("sync from backup round=%d"),
-	      lw6ker_game_state_get_rounds (pilot->backup));
-  ret = lw6ker_game_state_sync (target, pilot->backup);
+  lw6sys_mutex_lock (pilot->reference.global_mutex);
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("sync from reference round=%d"),
+	      lw6ker_game_state_get_rounds (pilot->reference.game_state));
+  ret = lw6ker_game_state_sync (target, pilot->reference.game_state);
+
+  lw6sys_mutex_unlock (pilot->reference.global_mutex);
 
   return ret;
 }
@@ -563,58 +649,34 @@ int
 lw6pil_pilot_sync_from_reference (lw6ker_game_state_t * target,
 				  lw6pil_pilot_t * pilot)
 {
-  int ret = 0;
-
-  lw6sys_mutex_lock (pilot->reference.global_mutex);
-
-  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("sync from reference round=%d"),
-	      lw6ker_game_state_get_rounds (pilot->reference.game_state));
-  ret = lw6ker_game_state_sync (target, pilot->reference.game_state);
-
-  lw6sys_mutex_unlock (pilot->reference.global_mutex);
-
-  return ret;
+  return _lw6pil_pilot_sync_from_reference (target,
+					    (_lw6pil_pilot_t *) pilot);
 }
 
-/**
- * lw6pil_pilot_sync_from_draft
- *
- * @target: the game_state structure which will get the informations.
- * @pilot: the object to get informations from.
- * @dirty_read: wether to allow dirty read or not
- *
- * Gets the informations from the pilot object, not being worried about
- * game consistency, this one will just return the latest version available.
- * It might even be in an inconsistent state, the position could reflect
- * a position which will never exist. Still, the data returned will not
- * correspond to a half-spread or half-moved game_state if dirty_read
- * is set to 0. In this case the data has at least some basic consistency 
- * and getting this does require some mutex lock, however wait time should 
- * be fairly small (max. a round). But, in a general manner, this function
- * is only used for display, and we do not care much if there's a small
- * glitch, we prefer fast & smooth display.
- *
- * Return value: 1 if OK, 0 if not.
- */
 int
-lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
-			      lw6pil_pilot_t * pilot, int dirty_read)
+_lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
+			       _lw6pil_pilot_t * pilot, int dirty_read)
 {
   int ret = 0;
+  int max_round;
   int draft_rounds;
   int reference_rounds;
   int current_round;
 
   current_round = lw6ker_game_state_get_rounds (target);
 
-  if (lw6pil_pilot_get_max_round (pilot) > current_round)
+  max_round =
+    _lw6pil_pilot_seq2round (pilot, _lw6pil_pilot_get_max_seq (pilot));
+  if (max_round > current_round)
     {
       if (dirty_read == LW6PIL_DIRTY_READ_NEVER)
 	{
 	  lw6sys_mutex_lock (pilot->draft.compute_mutex);
 	  lw6sys_mutex_lock (pilot->reference.compute_mutex);
 	}
-      if (lw6pil_pilot_get_max_round (pilot) > current_round)
+      max_round =
+	_lw6pil_pilot_seq2round (pilot, _lw6pil_pilot_get_max_seq (pilot));
+      if (max_round > current_round)
 	{
 	  draft_rounds =
 	    lw6ker_game_state_get_rounds (pilot->draft.game_state);
@@ -655,18 +717,35 @@ lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
 }
 
 /**
- * lw6pil_pilot_dirty_read
+ * lw6pil_pilot_sync_from_draft
  *
+ * @target: the game_state structure which will get the informations.
  * @pilot: the object to get informations from.
+ * @dirty_read: wether to allow dirty read or not
  *
- * Returns a direct access to the most up-to-date game_state, without
- * locking anything whatsoever. This is clearly to implement a dirty read
- * mode as the name of the function suggests.
+ * Gets the informations from the pilot object, not being worried about
+ * game consistency, this one will just return the latest version available.
+ * It might even be in an inconsistent state, the position could reflect
+ * a position which will never exist. Still, the data returned will not
+ * correspond to a half-spread or half-moved game_state if dirty_read
+ * is set to 0. In this case the data has at least some basic consistency 
+ * and getting this does require some mutex lock, however wait time should 
+ * be fairly small (max. a round). But, in a general manner, this function
+ * is only used for display, and we do not care much if there's a small
+ * glitch, we prefer fast & smooth display.
  *
  * Return value: 1 if OK, 0 if not.
  */
+int
+lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
+			      lw6pil_pilot_t * pilot, int dirty_read)
+{
+  return _lw6pil_pilot_sync_from_draft (target, (_lw6pil_pilot_t *) pilot,
+					dirty_read);
+}
+
 lw6ker_game_state_t *
-lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
+_lw6pil_pilot_dirty_read (_lw6pil_pilot_t * pilot)
 {
   lw6ker_game_state_t *ret = NULL;
   int draft_rounds = 0;
@@ -693,6 +772,49 @@ lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
   return ret;
 }
 
+/**
+ * lw6pil_pilot_dirty_read
+ *
+ * @pilot: the object to get informations from.
+ *
+ * Returns a direct access to the most up-to-date game_state, without
+ * locking anything whatsoever. This is clearly to implement a dirty read
+ * mode as the name of the function suggests.
+ *
+ * Return value: 1 if OK, 0 if not.
+ */
+lw6ker_game_state_t *
+lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_dirty_read ((_lw6pil_pilot_t *) pilot);
+}
+
+char *
+_lw6pil_pilot_repr (_lw6pil_pilot_t * pilot)
+{
+  char *ret = NULL;
+
+  if (pilot)
+    {
+      ret =
+	lw6sys_new_sprintf
+	("%u (%dx%dx%d commmit_seq=%" LW6SYS_PRINTF_LL "d, current_seq=%"
+	 LW6SYS_PRINTF_LL "d)", pilot->id,
+	 lw6ker_game_state_get_w (pilot->backup),
+	 lw6ker_game_state_get_h (pilot->backup),
+	 lw6ker_game_state_get_d (pilot->backup),
+	 _lw6pil_pilot_get_last_commit_seq (pilot),
+	 _lw6pil_pilot_get_reference_current_seq (pilot));
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("can't generate string id for NULL pilot"));
+    }
+
+  return ret;
+}
+
 /**
  * lw6pil_pilot_repr
  *
@@ -707,27 +829,15 @@ lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
 char *
 lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
 {
-  char *ret = NULL;
+  return _lw6pil_pilot_repr ((_lw6pil_pilot_t *) pilot);
+}
 
-  if (pilot)
-    {
-      ret =
-	lw6sys_new_sprintf
-	("%u (%dx%dx%d commmit_round=%d, current_round=%d)",
-	 pilot->id,
-	 lw6ker_game_state_get_w (pilot->backup),
-	 lw6ker_game_state_get_h (pilot->backup),
-	 lw6ker_game_state_get_d (pilot->backup),
-	 lw6pil_pilot_get_last_commit_round (pilot),
-	 lw6pil_pilot_get_reference_current_round (pilot));
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _x_ ("can't generate string id for NULL pilot"));
-    }
-
-  return ret;
+void
+_lw6pil_pilot_calibrate (_lw6pil_pilot_t * pilot, int64_t timestamp,
+			 int64_t seq)
+{
+  pilot->calibrate_timestamp = timestamp;
+  pilot->calibrate_seq = seq;
 }
 
 /**
@@ -735,7 +845,7 @@ lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
  *
  * @pilot: the object to calibrate
  * @timestamp: the current ticks setting (1000 ticks per second)
- * @round: the round expected to be returned with this ticks value
+ * @seq: the round expected to be returned with this ticks value
  *
  * Calibrates the pilot, that is, initializes it so that subsequent calls
  * to @lw6pil_pilot_get_round return consistent values.
@@ -743,155 +853,281 @@ lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
  * Return value: none.
  */
 void
-lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int64_t timestamp, int round)
+lw6pil_pilot_calibrate (lw6pil_pilot_t * pilot, int64_t timestamp,
+			int64_t seq)
 {
-  pilot->calibrate_ticks = timestamp;
-  pilot->calibrate_round = round;
+  return _lw6pil_pilot_calibrate ((_lw6pil_pilot_t *) pilot, timestamp, seq);
+}
+
+void
+_lw6pil_pilot_speed_up (_lw6pil_pilot_t * pilot, int seq_inc)
+{
+  pilot->calibrate_seq += seq_inc;
 }
 
 /**
  * lw6pil_pilot_speed_up
  *
  * @pilot: the pilot to speed up
- * @round_inc: the number of rounds
+ * @seq_inc: the number of seqs
  *
  * Re-calibrates the pilot so that it speeds up a bit.
- * This will basically increase next_round by round_inc.
+ * This will basically increase next_seq by seq_inc.
  *
  * Return value: none.
  */
 void
-lw6pil_pilot_speed_up (lw6pil_pilot_t * pilot, int round_inc)
+lw6pil_pilot_speed_up (lw6pil_pilot_t * pilot, int seq_inc)
 {
-  pilot->calibrate_round += round_inc;
+  _lw6pil_pilot_speed_up ((_lw6pil_pilot_t *) pilot, seq_inc);
+}
+
+void
+_lw6pil_pilot_slow_down (_lw6pil_pilot_t * pilot, int seq_dec)
+{
+  pilot->calibrate_seq -= seq_dec;
 }
 
 /**
  * lw6pil_pilot_slow_down
  *
  * @pilot: the pilot to speed up
- * @round_dec: the number of rounds
+ * @seq_dec: the number of seqs
  *
  * Re-calibrates the pilot so that it slows down a bit.
- * This will basically decrease next_round by round_inc.
+ * This will basically decrease next_seq by seq_inc.
  *
  * Return value: none.
  */
 void
-lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int round_dec)
+lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int seq_dec)
 {
-  pilot->calibrate_round -= round_dec;
+  _lw6pil_pilot_slow_down ((_lw6pil_pilot_t *) pilot, seq_dec);
+}
+
+int64_t
+_lw6pil_pilot_get_seq_0 (_lw6pil_pilot_t * pilot)
+{
+  return pilot->seq_0;
 }
 
 /**
- * lw6pil_pilot_get_next_round
+ * lw6pil_pilot_get_seq_0
+ *
+ * @pilot: pilot object to query
+ * 
+ * Get the initial seq (the one passed at object construction) which
+ * says what the seq was at round=0, it's just an offset.
+ *
+ * Return value: 64-bit integer
+ */
+int64_t
+lw6pil_pilot_get_seq_0 (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_get_seq_0 ((_lw6pil_pilot_t *) pilot);
+}
+
+int
+_lw6pil_pilot_seq2round (_lw6pil_pilot_t * pilot, int64_t seq)
+{
+  return (seq >= 10000000000L ? (seq - _lw6pil_pilot_get_seq_0 (pilot)) : -1);
+}
+
+/**
+ * lw6pil_pilot_seq2round
+ *
+ * @pilot: pilot object to work on
+ * @seq: the seq to convert
+ * 
+ * Converts a seq (64-bit) to a round (32-bit). 64-bit seqs are used
+ * to avoid out-of-range errors on very long games, OTOH a round is 32-bit
+ * to garantee the atomicity of its affection, even on platforms which
+ * are not native 64-bit.
+ *
+ * Return value: the round (32-bit integer)
+ */
+int
+lw6pil_pilot_seq2round (lw6pil_pilot_t * pilot, int64_t seq)
+{
+  return _lw6pil_pilot_seq2round ((_lw6pil_pilot_t *) pilot, seq);
+}
+
+int64_t
+_lw6pil_pilot_round2seq (_lw6pil_pilot_t * pilot, int round)
+{
+  return round + _lw6pil_pilot_get_seq_0 (pilot);
+}
+
+/**
+ * lw6pil_pilot_round2seq
+ *
+ * @pilot: pilot object to work on
+ * @round: the round to convert
+ * 
+ * Converts a round (32-bit) to a seq (64-bit). 64-bit seqs are used
+ * to avoid out-of-range errors on very long games, OTOH a round is 32-bit
+ * to garantee the atomicity of its affection, even on platforms which
+ * are not native 64-bit.
+ *
+ * Return value: the seq (64-bit integer)
+ */
+int64_t
+lw6pil_pilot_round2seq (lw6pil_pilot_t * pilot, int round)
+{
+  return _lw6pil_pilot_round2seq ((_lw6pil_pilot_t *) pilot, round);
+}
+
+int64_t
+_lw6pil_pilot_get_next_seq (_lw6pil_pilot_t * pilot, int64_t timestamp)
+{
+  int64_t ret = 0;
+  int64_t delta;
+
+  delta = timestamp - pilot->calibrate_timestamp;
+  delta *= (int64_t) pilot->backup->game_struct->rules.rounds_per_sec;
+  delta /= LW6SYS_TICKS_PER_SEC;
+  ret = pilot->calibrate_seq + (int) delta;
+
+  return ret;
+}
+
+/**
+ * lw6pil_pilot_get_next_seq
  *
  * @pilot: the object to query
  * @timestamp: the current ticks setting (1000 ticks per second)
  *
- * Returns the round one should use to generate new events/commands
+ * Returns the seq one should use to generate new events/commands
  * at a given time (given in ticks).
  *
  * Return value: none.
  */
-int
-lw6pil_pilot_get_next_round (lw6pil_pilot_t * pilot, int64_t timestamp)
+int64_t
+lw6pil_pilot_get_next_seq (lw6pil_pilot_t * pilot, int64_t timestamp)
 {
-  int ret = 0;
-  int64_t delta;
+  return _lw6pil_pilot_get_next_seq ((_lw6pil_pilot_t *) pilot, timestamp);
+}
 
-  delta = timestamp - pilot->calibrate_ticks;
-  delta *= (int64_t) pilot->backup->game_struct->rules.rounds_per_sec;
-  delta /= LW6SYS_TICKS_PER_SEC;
-  ret = pilot->calibrate_round + (int) delta;
+int64_t
+_lw6pil_pilot_get_last_commit_seq (_lw6pil_pilot_t * pilot)
+{
+  int64_t ret = 0;
+
+  ret = pilot->last_commit_seq;
 
   return ret;
 }
 
 /**
- * lw6pil_pilot_get_last_commit_round
+ * lw6pil_pilot_get_last_commit_seq
  *
  * @pilot: the object to query
  *
- * Returns the round of the last commit (reference game_state) for
+ * Returns the seq of the last commit (reference game_state) for
  * this object.
  *
- * Return value: the commit round (reference object)
+ * Return value: the commit seq (reference object)
  */
-int
-lw6pil_pilot_get_last_commit_round (lw6pil_pilot_t * pilot)
+int64_t
+lw6pil_pilot_get_last_commit_seq (lw6pil_pilot_t * pilot)
 {
-  int ret = 0;
+  return _lw6pil_pilot_get_last_commit_seq ((_lw6pil_pilot_t *) pilot);
+}
 
-  ret = pilot->last_commit_round;
+int64_t
+_lw6pil_pilot_get_reference_target_seq (_lw6pil_pilot_t * pilot)
+{
+  int64_t ret = 0;
+
+  ret = _lw6pil_pilot_round2seq (pilot, pilot->reference.target_round);
 
   return ret;
 }
 
 /**
- * lw6pil_pilot_get_reference_target_round
+ * lw6pil_pilot_get_reference_target_seq
  *
  * @pilot: the object to query
  *
- * Returns the round which is targetted in the reference game_state,
+ * Returns the seq which is targetted in the reference game_state,
  * this is 'how far computation will go in the reference game_state
  * if no new commands are issued'. Note that there can always
  * be some commands which are not yet processed, so you should not
  * rely on this too heavily, however it gives a good idea of how
  * things are going.
  *
- * Return value: the target round (reference object)
+ * Return value: the target seq (reference object)
  */
-int
-lw6pil_pilot_get_reference_target_round (lw6pil_pilot_t * pilot)
+int64_t
+lw6pil_pilot_get_reference_target_seq (lw6pil_pilot_t * pilot)
 {
-  int ret = 0;
+  return _lw6pil_pilot_get_reference_target_seq ((_lw6pil_pilot_t *) pilot);
+}
 
-  ret = pilot->reference.target_round;
+int64_t
+_lw6pil_pilot_get_reference_current_seq (_lw6pil_pilot_t * pilot)
+{
+  int64_t ret = 0;
+
+  ret = _lw6pil_pilot_round2seq (pilot, pilot->reference.current_round);
 
   return ret;
 }
 
 /**
- * lw6pil_pilot_get_reference_current_round
+ * lw6pil_pilot_get_reference_current_seq
  *
  * @pilot: the object to query
  *
- * Returns the current round in the reference game_state. There's no
+ * Returns the current seq in the reference game_state. There's no
  * lock on this call so don't rely on this too heavily, it just
  * gives you an idea of wether the pilot is very late on its
  * objectives or just on time.
  *
- * Return value: the current round (reference object)
+ * Return value: the current seq (reference object)
  */
-int
-lw6pil_pilot_get_reference_current_round (lw6pil_pilot_t * pilot)
+int64_t
+lw6pil_pilot_get_reference_current_seq (lw6pil_pilot_t * pilot)
 {
-  int ret = 0;
+  return _lw6pil_pilot_get_reference_current_seq ((_lw6pil_pilot_t *) pilot);
+}
 
-  ret = pilot->reference.current_round;
+int64_t
+_lw6pil_pilot_get_max_seq (_lw6pil_pilot_t * pilot)
+{
+  int64_t ret = 0;
+
+  ret =
+    _lw6pil_pilot_round2seq (pilot,
+			     lw6sys_max (pilot->reference.current_round,
+					 pilot->draft.current_round));
 
   return ret;
 }
 
 /**
- * lw6pil_pilot_get_max_round
+ * lw6pil_pilot_get_max_seq
  *
  * @pilot: the object to query
  *
- * Returns the max current round in the reference or draft
+ * Returns the max current seq in the reference or draft
  * game states. No lock on this call so don't rely on this
  * too heavily, it just gives you an idea of computation state.
  *
- * Return value: the current round (reference object)
+ * Return value: the current seq (reference object)
  */
+int64_t
+lw6pil_pilot_get_max_seq (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_get_max_seq ((_lw6pil_pilot_t *) pilot);
+}
+
 int
-lw6pil_pilot_get_max_round (lw6pil_pilot_t * pilot)
+_lw6pil_pilot_is_over (_lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
-  ret =
-    lw6sys_max (pilot->reference.current_round, pilot->draft.current_round);
+  ret = pilot->reference.over ? 1 : 0;
 
   return ret;
 }
@@ -907,10 +1143,21 @@ lw6pil_pilot_get_max_round (lw6pil_pilot_t * pilot)
  */
 int
 lw6pil_pilot_is_over (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_is_over ((_lw6pil_pilot_t *) pilot);
+}
+
+int
+_lw6pil_pilot_did_cursor_win (_lw6pil_pilot_t * pilot, u_int16_t cursor_id)
 {
   int ret = 0;
 
-  ret = pilot->reference.over ? 1 : 0;
+  if (pilot->reference.game_state)
+    {
+      ret =
+	lw6ker_game_state_did_cursor_win (pilot->reference.game_state,
+					  cursor_id);
+    }
 
   return ret;
 }
@@ -927,15 +1174,88 @@ lw6pil_pilot_is_over (lw6pil_pilot_t * pilot)
  */
 int
 lw6pil_pilot_did_cursor_win (lw6pil_pilot_t * pilot, u_int16_t cursor_id)
+{
+  return _lw6pil_pilot_did_cursor_win ((_lw6pil_pilot_t *) pilot, cursor_id);
+}
+
+int
+_lw6pil_pilot_get_winner (_lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
   if (pilot->reference.game_state)
     {
       ret =
-	lw6ker_game_state_did_cursor_win (pilot->reference.game_state,
-					  cursor_id);
+	lw6ker_game_state_get_winner (pilot->reference.game_state,
+				      LW6MAP_TEAM_COLOR_INVALID);
     }
 
   return ret;
 }
+
+/**
+ * lw6pil_pilot_get_winner
+ *
+ * @pilot: the object to query
+ *
+ * Gets the winner color.
+ *
+ * Return value: a team color, -1 if no winner and/or error.
+ */
+int
+lw6pil_pilot_get_winner (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_get_winner ((_lw6pil_pilot_t *) pilot);
+}
+
+int
+_lw6pil_pilot_get_looser (_lw6pil_pilot_t * pilot)
+{
+  int ret = 0;
+
+  if (pilot->reference.game_state)
+    {
+      ret =
+	lw6ker_game_state_get_looser (pilot->reference.game_state,
+				      LW6MAP_TEAM_COLOR_INVALID);
+    }
+
+  return ret;
+}
+
+/**
+ * lw6pil_pilot_get_looser
+ *
+ * @pilot: the object to query
+ *
+ * Gets the looser color.
+ *
+ * Return value: a team color, -1 if no looser and/or error.
+ */
+int
+lw6pil_pilot_get_looser (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_get_looser ((_lw6pil_pilot_t *) pilot);
+}
+
+lw6pil_local_cursors_t *
+_lw6pil_pilot_get_local_cursors (_lw6pil_pilot_t * pilot)
+{
+  return &(pilot->local_cursors);
+}
+
+/**
+ * lw6pil_pilot_get_local_cursors
+ *
+ * @pilot: object to query
+ *
+ * Returns a pointer on the local_cursors struct used within
+ * the object. Beware, this is the *real* pointer, not a copy...
+ *
+ * Return value: pointer on internal object
+ */
+lw6pil_local_cursors_t *
+lw6pil_pilot_get_local_cursors (lw6pil_pilot_t * pilot)
+{
+  return _lw6pil_pilot_get_local_cursors ((_lw6pil_pilot_t *) pilot);
+}
