@@ -1,6 +1,6 @@
  /*
     Liquid War 6 is a unique multiplayer wargame.
-    Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+    Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,10 +31,10 @@
 void
 _lw6pil_spread_thread_func (_lw6pil_spread_data_t * spread_data)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("spread with team_mask %x begin"),
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("spread with team_mask %x begin"),
 	      spread_data->team_mask);
   lw6ker_game_state_do_spread (spread_data->game_state,
 			       spread_data->team_mask);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("spread with team_mask %x end"),
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("spread with team_mask %x end"),
 	      spread_data->team_mask);
 }
