@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,11 +28,34 @@
 #include "mod-ogg-internal.h"
 
 extern void
-_mod_ogg_set_sound_volume (_mod_ogg_context_t * ogg_context, float volume)
+_mod_ogg_set_fx_volume (_mod_ogg_context_t * ogg_context, float volume)
 {
-  ogg_context->volume.sound = volume;
+  int i = 0;
 
-  Mix_Volume (-1, volume * MIX_MAX_VOLUME);
+  ogg_context->volume.fx = volume;
+
+  for (i = _MOD_OGG_CHANNEL_FX0; i < ogg_context->mixer.nb_channels; ++i)
+    {
+      Mix_Volume (i, volume * MIX_MAX_VOLUME);
+    }
+}
+
+extern void
+_mod_ogg_set_water_volume (_mod_ogg_context_t * ogg_context, float volume)
+{
+  ogg_context->volume.water = volume;
+
+  if (ogg_context->mixer.nb_channels > _MOD_OGG_CHANNEL_WATER2)
+    {
+      Mix_Volume (_MOD_OGG_CHANNEL_WATER1, volume * MIX_MAX_VOLUME);
+      Mix_Volume (_MOD_OGG_CHANNEL_WATER2, volume * MIX_MAX_VOLUME);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("not even channels (%d) to handle water"),
+		  ogg_context->mixer.nb_channels);
+    }
 }
 
 extern void
