@@ -31,11 +31,10 @@
 
 #define COPYRIGHT "Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>"
 #define LICENSE "GPLv3+ (GNU GPL version 3 or later)"
-#define URL "http://www.gnu.org/software/liquidwar6/"
+#define HOME_URL "http://www.gnu.org/software/liquidwar6/"
+#define BUGS_URL "http://savannah.gnu.org/bugs/?func=additem&group=liquidwar6"
 #define TOP_SRCDIR_TEST_FILE "liquidwar6.spec.in"
 #define TOP_SRCDIR_MAX_UNPARENT 4
-#define ENABLE_YES "yes"
-#define ENABLE_NO "no"
 
 /**
  * lw6sys_build_get_package_tarname:
@@ -201,7 +200,7 @@ lw6sys_build_get_license ()
 }
 
 /**
- * lw6sys_build_get_url:
+ * lw6sys_build_get_home_url:
  *
  * Returns the URL of the game, its homepage.
  *
@@ -209,9 +208,23 @@ lw6sys_build_get_license ()
  *   Must not be freed.
  */
 char *
-lw6sys_build_get_url ()
+lw6sys_build_get_home_url ()
 {
-  return URL;
+  return HOME_URL;
+}
+
+/**
+ * lw6sys_build_get_bugs_url:
+ *
+ * Returns the URL for bugs, the bug reports page.
+ *
+ * Return value: a non-NULL string, single line whithout '\n' at the end. 
+ *   Must not be freed.
+ */
+char *
+lw6sys_build_get_bugs_url ()
+{
+  return BUGS_URL;
 }
 
 /**
@@ -408,6 +421,40 @@ lw6sys_build_get_host_os ()
   return LW6_HOST_OS;
 }
 
+/**
+ * lw6sys_build_is_gnu:
+ *
+ * Tells wether the program was compiled for a GNU system, or not.
+ *
+ * Return value: 1 if compiled on windows, 0 if not
+ */
+int
+lw6sys_build_is_gnu ()
+{
+#ifdef LW6_GNU
+  return 1;
+#else
+  return 0;
+#endif
+}
+
+/**
+ * lw6sys_build_is_unix:
+ *
+ * Tells wether the program was compiled for a UNIX system, or not.
+ *
+ * Return value: 1 if compiled on windows, 0 if not
+ */
+int
+lw6sys_build_is_unix ()
+{
+#ifdef LW6_UNIX
+  return 1;
+#else
+  return 0;
+#endif
+}
+
 /**
  * lw6sys_build_is_ms_windows:
  *
@@ -619,9 +666,9 @@ char *
 lw6sys_build_get_enable_console ()
 {
 #ifdef LW6_CONSOLE
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -636,9 +683,9 @@ char *
 lw6sys_build_get_enable_gtk ()
 {
 #ifdef LW6_GTK
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -653,9 +700,9 @@ char *
 lw6sys_build_get_enable_mod_gl ()
 {
 #ifdef MOD_GL
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -670,9 +717,9 @@ char *
 lw6sys_build_get_enable_mod_csound ()
 {
 #ifdef MOD_CSOUND
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -687,9 +734,9 @@ char *
 lw6sys_build_get_enable_mod_ogg ()
 {
 #ifdef MOD_OGG
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -704,9 +751,9 @@ char *
 lw6sys_build_get_enable_mod_http ()
 {
 #ifdef MOD_HTTP
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -721,9 +768,9 @@ char *
 lw6sys_build_get_enable_openmp ()
 {
 #ifdef LW6_OPENMP
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -738,9 +785,9 @@ char *
 lw6sys_build_get_enable_optimize ()
 {
 #ifdef LW6_OPTIMIZE
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -755,9 +802,9 @@ char *
 lw6sys_build_get_enable_allinone ()
 {
 #ifdef LW6_ALLINONE
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -772,9 +819,9 @@ char *
 lw6sys_build_get_enable_fullstatic ()
 {
 #ifdef LW6_FULLSTATIC
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -789,9 +836,9 @@ char *
 lw6sys_build_get_enable_paranoid ()
 {
 #ifdef LW6_PARANOID
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -806,9 +853,9 @@ char *
 lw6sys_build_get_enable_gprof ()
 {
 #ifdef LW6_GPROF
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -823,9 +870,9 @@ char *
 lw6sys_build_get_enable_instrument ()
 {
 #ifdef LW6_INSTRUMENT
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -840,9 +887,9 @@ char *
 lw6sys_build_get_enable_profiler ()
 {
 #ifdef LW6_PROFILER
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -857,9 +904,9 @@ char *
 lw6sys_build_get_enable_gcov ()
 {
 #ifdef LW6_GCOV
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -874,9 +921,9 @@ char *
 lw6sys_build_get_enable_valgrind ()
 {
 #ifdef LW6_VALGRIND
-  return ENABLE_YES;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_YES;	// do not translate this, could be interpreted by a script
 #else
-  return ENABLE_NO;		// do not translate this, could be interpreted by a script
+  return LW6SYS_BUILD_ENABLE_NO;	// do not translate this, could be interpreted by a script
 #endif
 }
 
@@ -915,7 +962,8 @@ lw6sys_build_get_bin_id ()
   lw6sys_checksum_update_str (&checksum_global,
 			      lw6sys_build_get_copyright ());
   lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_license ());
-  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_url ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_home_url ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_bugs_url ());
   lw6sys_checksum_update_str (&checksum_global,
 			      lw6sys_build_get_configure_args ());
   lw6sys_checksum_update_str (&checksum_global,
@@ -932,6 +980,8 @@ lw6sys_build_get_bin_id ()
 				lw6sys_build_get_pointer_size ());
   lw6sys_checksum_update_int32 (&checksum_global, lw6sys_build_is_x86 ());
   lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_host_os ());
+  lw6sys_checksum_update_int32 (&checksum_global, lw6sys_build_is_gnu ());
+  lw6sys_checksum_update_int32 (&checksum_global, lw6sys_build_is_unix ());
   lw6sys_checksum_update_int32 (&checksum_global,
 				lw6sys_build_is_ms_windows ());
   lw6sys_checksum_update_int32 (&checksum_global,
@@ -1027,8 +1077,10 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_copyright ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build license is \"%s\""),
 	      lw6sys_build_get_license ());
-  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build url is \"%s\""),
-	      lw6sys_build_get_url ());
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build home url is \"%s\""),
+	      lw6sys_build_get_home_url ());
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build bug url is \"%s\""),
+	      lw6sys_build_get_bugs_url ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build configure args is \"%s\""),
 	      lw6sys_build_get_configure_args ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build gcc_version is \"%s\""),
@@ -1049,6 +1101,10 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_pointer_size ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build host os is \"%s\""),
 	      lw6sys_build_get_host_os ());
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build gnu is %d"),
+	      lw6sys_build_is_gnu ());
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build unix is %d"),
+	      lw6sys_build_is_unix ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build ms windows is %d"),
 	      lw6sys_build_is_ms_windows ());
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build mac os x is %d"),
